@@ -1,4 +1,4 @@
-/* $Id: events.c,v 1.15 2001/02/07 13:32:25 amai Exp $ */
+/* $Id: events.c,v 1.19 2002/03/21 18:08:15 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -49,16 +49,17 @@
 #include <sys/select.h>
 #endif
 
-#include <Xm/Xm.h>
-#include <Xm/MwmUtil.h>
-#include "mwm.h"
-
-#include <X11/extensions/shape.h>
-
 #include <Xm/XmosP.h>
 #if XmVERSION >= 2
 #include <XmI/XmI.h>
 #endif
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
+#include <X11/extensions/shape.h>
+
+#include "mwm.h"
+
 
 /*
  * shorthand defines
@@ -68,11 +69,7 @@
 #define MOD_MASK	(ShiftMask|ControlMask|Mod1Mask|Mod2Mask|Mod3Mask|\
 			 Mod4Mask | Mod5Mask)
 
-extern int menuFromFrameOrWindowOrTitlebar;
-MwmWindow *win;			/* the current mwm window */
 static int ShapeEventBase, ShapeErrorBase;
-extern volatile int alarmed;
-extern Bool EnablePagerRedraw;
 
 /*
  * Waits Mwm.click_time, or until it is evident that the user is not
