@@ -1,4 +1,4 @@
-/* $Id: icons.c,v 1.14 2001/05/17 13:03:27 amai Exp $ */
+/* $Id: icons.c,v 1.16 2001/06/22 19:06:04 amai Exp $ */
 /****************************************************************************
  * This module is mostly all new
  * by Rob Nation
@@ -15,6 +15,7 @@
 #include <LTconfig.h>
 
 #include <stdio.h>
+#include <string.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -22,18 +23,19 @@
 #include <fcntl.h>
 #endif
 
-#include <Xm/Xm.h>
-#include <Xm/MwmUtil.h>
-#include "mwm.h"
-
+#include <X11/Intrinsic.h>
 #include <X11/extensions/shape.h>
 
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
 #if XmVERSION >= 2
 #include <Xm/XpmP.h>
 #else
 #include <XmI/XmXpm.h>
 #endif
 
+#include "mwm.h"
+
 
 #define def_bitmap_width 50
 #define def_bitmap_height 50
@@ -87,7 +89,7 @@ static unsigned char def_bitmap_bits[] =
  * Oh well.
  */
 static char *
-find_icon_file(char *icon, char *pathlist, int type)
+find_icon_file(const char *icon, const char *pathlist, int type)
 {
     char *path;
     char *dir_end;
@@ -513,7 +515,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     tmp_win->icon_p_height = 0;
     tmp_win->icon_p_width = 0;
 
-    if ((Mwm.icon_decoration & XmICON_IMAGE) && tmp_win->use_client_icon)
+    if ((scr->icon_decoration & XmICON_IMAGE) && tmp_win->use_client_icon)
     {
 	/* First, See if the app supplies its own icon window */
 	if ((tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0) &&
@@ -535,7 +537,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
 	    (tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0))
 	    get_bitmap_file(scr, tmp_win);
     }
-    else if (Mwm.icon_decoration & XmICON_IMAGE)
+    else if (scr->icon_decoration & XmICON_IMAGE)
     {
 	/* First, check for a color pixmap */
 	if (tmp_win->icon_image != NULL &&
@@ -559,7 +561,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     }
 
     /* If all that failed, use the default */
-    if ((Mwm.icon_decoration & XmICON_IMAGE) &&
+    if ((scr->icon_decoration & XmICON_IMAGE) &&
 	(tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0))
     {
 	tmp_win->icon_pixmap = XCreateBitmapFromData(dpy,
@@ -574,7 +576,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     if (tmp_win->flags & SHAPED_ICON)
 	tmp_win->icon_border_width = 0;
     else
-	tmp_win->icon_border_width = Mwm.frame_border_width;
+	tmp_win->icon_border_width = scr->frame_border_width;
 
     /* figure out the icon label size */
     tmp_win->icon_t_width =
@@ -620,7 +622,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
 			     ExposureMask | KeyPressMask | EnterWindowMask |
 			     FocusChangeMask);
 
-    if (Mwm.icon_decoration & (XmICON_LABEL | XmICON_ACTIVELABEL))
+    if (scr->icon_decoration & (XmICON_LABEL | XmICON_ACTIVELABEL))
     {
 	tmp_win->icon_w =
 	    XCreateWindow(dpy, scr->root_win,
@@ -632,7 +634,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     else
 	tmp_win->icon_w = None;
 
-    if (Mwm.icon_decoration & XmICON_IMAGE)
+    if (scr->icon_decoration & XmICON_IMAGE)
     {
         /* int i; */
 
@@ -776,7 +778,7 @@ ICON_DrawWindow(ScreenInfo *scr, MwmWindow *tmp)
     if (tmp->icon_pixmap_w != None)
 	MISC_FlushExpose(tmp->icon_pixmap_w);
 
-    if (tmp == scr->mwm_highlight && (Mwm.icon_decoration & XmICON_ACTIVELABEL)
+    if (tmp == scr->mwm_highlight && (scr->icon_decoration & XmICON_ACTIVELABEL)
  && tmp->icon_active_label != NoName && tmp->icon_active_label != NULL
       && tmp->icon_active_label[0] != '\0')
 	label = tmp->icon_active_label;
@@ -950,7 +952,7 @@ ICON_DrawWindow(ScreenInfo *scr, MwmWindow *tmp)
 	char *label;
 
 	if (tmp == scr->mwm_highlight &&
-	    (Mwm.icon_decoration & XmICON_ACTIVELABEL) &&
+	    (scr->icon_decoration & XmICON_ACTIVELABEL) &&
 	    tmp->icon_active_label != NoName &&
 	    tmp->icon_active_label != NULL &&
 	    tmp->icon_active_label[0] != '\0')
@@ -1004,7 +1006,7 @@ ICON_UpdateWindow(ScreenInfo *scr, MwmWindow *tmp, Boolean force)
 	return;
 
     if ((force || (tmp == scr->mwm_highlight &&
-	 (Mwm.icon_decoration & XmICON_ACTIVELABEL))) &&
+	 (scr->icon_decoration & XmICON_ACTIVELABEL))) &&
 	tmp->icon_active_label != NoName &&
 	tmp->icon_active_label != NULL &&
 	tmp->icon_active_label[0] != '\0')
