@@ -1,6 +1,6 @@
 /**
  *
- * $Id: MrmTypes.h,v 1.5 2000/12/06 14:18:00 amai Exp $
+ * $Id: MrmTypes.h,v 1.7 2001/09/10 10:07:19 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2000 LessTif Development Team
@@ -197,6 +197,7 @@ FontM *FontMNew(char *name);
 XBitmapFile *XBitmapFileNew(char *name);
 
 void FontMEmit(FontM * this);
+FontElement *FontElementNew(FontSet * theFontSet, FontM * theFont);
 void ColorEmit(Color *this);
 void ColorSetAddress(Color *this);
 void XBitmapFileEmit(XBitmapFile *this);
@@ -219,7 +220,6 @@ void FontSetName(FontSet * this, char *name);
 FontTable *FontTableNew(void);
 void FontTableAppend(FontTable * this, FontSet * theFontSet, FontM * theFont);
 
-void ExpressionTypeDelete(ExpressionType *expr);
 CString *CStringAdd(CString *this, CString *s);
 
 #endif /* #ifndef _MRMTYPES_H */
