@@ -1,9 +1,9 @@
 /**
  *
- * $Id: main.c,v 1.9 2001/05/01 09:28:55 amai Exp $
+ * $Id: main.c,v 1.10 2001/07/29 16:32:18 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -27,7 +27,7 @@
  *
 */
 
-static char *rcsid = "$Id: main.c,v 1.9 2001/05/01 09:28:55 amai Exp $";
+static char *rcsid = "$Id: main.c,v 1.10 2001/07/29 16:32:18 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -37,7 +37,7 @@ static char *rcsid = "$Id: main.c,v 1.9 2001/05/01 09:28:55 amai Exp $";
 #include <unistd.h>
 
 #ifdef HAVE_GETOPT
-#ifdef CYGWIN
+#ifdef __CYGWIN__
 #include <getopt.h>
 #endif
 #else
