@@ -1,8 +1,9 @@
 /**
  *
- * $Id: MenuShell.h,v 1.1 1997/02/20 22:29:17 miers Exp $
+ * $Id: MenuShell.h,v 1.2 2000/09/23 14:51:40 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef XM_MENUSHELL_H
-#define XM_MENUSHELL_H
+#ifndef _XM_MENUSHELL_H
+#define _XM_MENUSHELL_H
 
 #include <Xm/Xm.h>
 
@@ -46,4 +47,4 @@ Widget XmCreateMenuShell(Widget parent, String name, ArgList arglist, Cardinal a
 }
 #endif
 
-#endif /* XM_MENUSHELL_H */
+#endif /* _XM_MENUSHELL_H */
