@@ -1,6 +1,6 @@
 /**
  *
- * $Id: PrimitiveP.h,v 1.4 2000/09/29 22:51:55 amai Exp $
+ * $Id: PrimitiveP.h,v 1.4 2000/09/23 14:51:40 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2000 LessTif Development Team
@@ -86,11 +86,6 @@ typedef struct {
     GC highlight_GC;
     GC top_shadow_GC;
     GC bottom_shadow_GC;
-
-    XtCallbackList convert_callback; /* new in 2.0 */
-    XtCallbackList popup_handler_callback; /* new in 2.0 */
-    XmDirection layout_direction; /* new in 2.0 */
-
 } XmPrimitivePart;
 
 /* Define the full instance record */
