@@ -1,9 +1,9 @@
 /**
  *
- * $Id: IconGP.h,v 1.4 2000/09/23 14:51:42 amai Exp $
+ * $Id: IconGP.h,v 1.9 2001/12/26 07:00:40 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
+ * Copyright (C) 1997-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -50,24 +50,28 @@ typedef struct _XmIconGCacheObjClassRec {
 extern XmIconGCacheObjClassRec xmIconGCacheObjClassRec;
 
 typedef struct _XmIconGCacheObjPart {
-    XmRenderTable render_table;
-    GC selected_gc;
-    GC inverse_gc;
-    Pixel background;
-    Pixel foreground;
-    Pixel top_shadow_color;
-    Pixel bottom_shadow_color;
-    Pixel highlight_color;
-    Pixmap background_pixmap;
-    Pixmap top_shadow_pixmap;
-    Pixmap bottom_shadow_pixmap;
-    Pixmap highlight_pixmap;
-    GC normal_gc;
-    GC background_gc;
-    GC insensitive_gc;
-    GC top_shadow_gc;
-    GC bottom_shadow_gc;
-    GC highlight_gc;
+    XmRenderTable	render_table;
+    GC			selected_gc;
+    GC			inverse_gc;
+    Pixel		background;
+    Pixel		foreground;
+    Pixel		top_shadow_color;
+    Pixel		bottom_shadow_color;
+    Pixel		highlight_color;
+    Pixmap		background_pixmap;
+    Pixmap		top_shadow_pixmap;
+    Pixmap		bottom_shadow_pixmap;
+    Pixmap		highlight_pixmap;
+    GC			normal_gc;
+    GC			background_gc;
+    GC			insensitive_gc;
+    GC			top_shadow_gc;
+    GC			bottom_shadow_gc;
+    GC			highlight_gc;
+    unsigned char	alignment;
+    Dimension		spacing;
+    Dimension		margin_width;
+    Dimension		margin_height;
 } XmIconGCacheObjPart;
 
 typedef struct _XmIconGCacheObjRec {
@@ -126,45 +130,29 @@ typedef struct _XmIconGadgetRec {
 } XmIconGadgetRec;
 
 
-#define IG_ViewType(w) \
-    (((XmIconGadget)(w))->icong.view_type)
-
-#define IG_LabelString(w) \
-    (((XmIconGadget)(w))->icong.label_string)
-
-#define IG_NormalGC(w) \
-    (((XmIconGadget)(w))->icong.cache->normal_gc)
-
-#define IG_BackgroundGC(w) \
-    (((XmIconGadget)(w))->icong.cache->background_gc)
-
-#define IG_Cache(w) \
-    (((XmIconGadget)(w))->icong.cache)
-
-#define IG_ClassCachePart(w) \
-    (((XmIconGadgetClass)xmIconGadgetClass)->gadget_class.cache_part)
-
-#define IG_LargeIconMask(w) \
-       (((XmIconGadget)(w))->icong.large_icon_mask)
-
-#define IG_LargeIconPixmap(w) \
-       (((XmIconGadget)(w))->icong.large_icon_pixmap)
-
-#define IG_SmallIconMask(w) \
-       (((XmIconGadget)(w))->icong.small_icon_mask)
-
-#define IG_SmallIconPixmap(w) \
-       (((XmIconGadget)(w))->icong.small_icon_pixmap)
-
-#define IG_RenderTable(w) \
-       (((XmIconGadget)(w))->icong.cache->render_table)
+#define IG_VisualEmphasis(w)	(((XmIconGadget)(w))->icong.visual_emphasis)
+#define IG_DetailCount(w)	(((XmIconGadget)(w))->icong.detail_count)
+#define IG_ViewType(w)		(((XmIconGadget)(w))->icong.view_type)
+#define IG_LabelString(w)	(((XmIconGadget)(w))->icong.label_string)
+#define IG_NormalGC(w)		(((XmIconGadget)(w))->icong.cache->normal_gc)
+#define IG_SelectedGC(w)	(((XmIconGadget)(w))->icong.cache->selected_gc)
+#define IG_BackgroundGC(w)	(((XmIconGadget)(w))->icong.cache->background_gc)
+#define IG_Cache(w)		(((XmIconGadget)(w))->icong.cache)
+#define IG_ClassCachePart(w)	(((XmIconGadgetClass)xmIconGadgetClass)->gadget_class.cache_part)
+#define IG_LargeIconMask(w)	(((XmIconGadget)(w))->icong.large_icon_mask)
+#define IG_LargeIconPixmap(w)	(((XmIconGadget)(w))->icong.large_icon_pixmap)
+#define IG_SmallIconMask(w)	(((XmIconGadget)(w))->icong.small_icon_mask)
+#define IG_SmallIconPixmap(w)	(((XmIconGadget)(w))->icong.small_icon_pixmap)
+#define IG_RenderTable(w)	(((XmIconGadget)(w))->icong.cache->render_table)
+#define IG_Alignment(w)		(((XmIconGadget)(w))->icong.cache->alignment)
+#define IG_Spacing(w)		(((XmIconGadget)(w))->icong.cache->spacing)
+#define IG_MarginHeight(w)	(((XmIconGadget)(w))->icong.cache->margin_height)
+#define IG_MarginWidth(w)	(((XmIconGadget)(w))->icong.cache->margin_width)
 
 /* weird Motif backwards compatibility function.  I don't care if it ever
  * gets implemented or not */
 extern void _XmClearBGCompatibility(Widget pbg);
 
-extern int _XmIconCacheCompare(XtPointer A, XtPointer B);
-
 #ifdef __cplusplus
 }
 #endif
