@@ -1,9 +1,9 @@
 /**
  *
- * $Id: uilparse.c,v 1.11 2001/03/31 10:27:57 amai Exp $
+ * $Id: uilparse.c,v 1.13 2002/04/13 09:36:27 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright (C) 1995-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  */ 
 
-static const char rcsid[] = "$Id: uilparse.c,v 1.11 2001/03/31 10:27:57 amai Exp $";
+static const char rcsid[] = "$Id: uilparse.c,v 1.13 2002/04/13 09:36:27 amai Exp $";
 
 
 #include <LTconfig.h>
@@ -35,11 +35,12 @@ static const char rcsid[] = "$Id: uilparse.c,v 1.11 2001/03/31 10:27:57 amai Exp
 
 #ifdef HAVE_LIBGEN_H
 #include <libgen.h>    /* for basename() */
-#else
-#include "LTmisc.h"
 #endif
 
+#include <X11/Intrinsic.h>
+#include <XmI/LTmisc.h>
 #include <XmI/UilI.h>
+
 #include <uil/UilSymGl.h>
 
 #include <XmI/DebugUtil.h>
@@ -100,8 +101,10 @@ _uil_parse_module(Uil_parse_data *pd)
 
     pd->desc->parse_tree_root = (char *)root;
 
-    strncpy(root->full_file_name, pd->command->source_file, 255);
-    strncpy(root->file_name, basename(pd->command->source_file), 255);
+    strncpy(root->full_file_name, pd->command->source_file, sizeof(root->full_file_name)-1);
+    root->full_file_name[sizeof(root->full_file_name)-1]='\0';
+    strncpy(root->file_name, basename(pd->command->source_file), sizeof(root->file_name)-1);
+    root->file_name[sizeof(root->file_name)-1]='\0';
 
     root->module_hdr =
         (sym_module_entry_type *)XtCalloc(1, sizeof(sym_module_entry_type));
