@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.34 2001/05/21 11:55:37 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.42 2003/09/18 15:42:08 dannybackx Exp $
  *
- * Copyright (C) 1997-1998 Free Software Foundation, Inc.
- * Copyright (C) 1998-2001 LessTif Development Team
+ * Copyright (C) 1997, 1998 Free Software Foundation, Inc.
+ * Copyright  1998, 1999, 2000, 2001, 2003 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,11 +23,12 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.34 2001/05/21 11:55:37 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.42 2003/09/18 15:42:08 dannybackx Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
@@ -113,6 +114,11 @@ static XtResource resources[] =
 	sizeof(unsigned char), Offset(arrow_layout),
 	XmRImmediate, (XtPointer)XmARROWS_END
     },
+    {
+	XmNarrowOrientation, XmCArrowOrientation, XmRArrowOrientation,
+	sizeof(unsigned char), Offset(arrow_orientation),
+	XmRImmediate, (XtPointer)XmARROWS_VERTICAL
+    },
     {
 	XmNarrowSize, XmCArrowSize, XmRArrowSize,
 	sizeof(Dimension), Offset(arrow_size),
@@ -199,6 +205,9 @@ static XtActionsRec actions[] =
 	{"SpinBoxFocusOut",	SpinBoxFocusOut}
 };
 
+/*
+ * Constraint resources, i.e. resources magically added to all XmSpinBox children.
+ */
 #define Offset(field) XtOffsetOf(XmSpinBoxConstraintRec, spinBox.field)
 static XtResource ConstraintResources[] = {
     {
@@ -236,6 +245,11 @@ static XtResource ConstraintResources[] = {
 	sizeof(int), Offset(position),
 	XmRImmediate, (XtPointer)0
     },
+    {
+	XmNpositionType, XmCPositionType, XmRChar,
+	sizeof(unsigned char), Offset(position_type),
+	XmRImmediate, (XtPointer)XmPOSITION_VALUE
+    },
     {
 	XmNspinBoxChildType, XmCSpinBoxChildType, XmRSpinBoxChildType,
 	sizeof(unsigned char), Offset(sb_child_type),
@@ -245,7 +259,7 @@ static XtResource ConstraintResources[] = {
 	XmNvalues, XmCValues, XmRXmStringTable,
 	sizeof(XmStringTable), Offset(values),
 	XmRImmediate, (XtPointer)NULL
-    }
+    },
 };
 
 /* FIX ME - this should go in other files */
@@ -454,7 +468,7 @@ initialize(Widget request, Widget nw,
 {
 	XmScrollFrameTrait	t;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, nw,
+	DEBUGOUT(_LtDebug(__FILE__, nw,
 		      "SpinBox initialize: w/h %d %d\n",
 		      XtWidth(nw), XtHeight(nw)));
 #if 0
@@ -491,7 +505,7 @@ SetValues(Widget old, Widget request, Widget nw,
     Boolean	need_refresh = False,
 		need_layout = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, nw, "SetValues()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, nw, "SetValues()\n"));
 
 #define	NE(x)	(x(old) != x(nw))
 
@@ -508,6 +522,8 @@ SetValues(Widget old, Widget request, Widget nw,
      || NE(SPB_UpWidth) || NE(SPB_UpHeight)
      || NE(SPB_DownX) || NE(SPB_DownY)
      || NE(SPB_DownWidth) || NE(SPB_DownHeight)) {
+	/* FIX ME What to do ? This'll recalculate (i.e. overrule) them again. */
+	need_layout = True;
     }
 
     if (need_layout) {
@@ -522,7 +538,8 @@ SetValues(Widget old, Widget request, Widget nw,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Expose\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Expose up %d %d down %d %d\n",
+		SPB_UpX(w), SPB_UpY(w), SPB_DownX(w), SPB_DownY(w)));
 
 	_XmRedisplayGadgets(w, event, region);
 
@@ -535,7 +552,7 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_UpWidth(w),
 			SPB_UpHeight(w),
 			SPB_DetailShadowThickness(w),
-			XmARROW_RIGHT);
+			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_RIGHT : XmARROW_UP);
 	XmeDrawArrow(XtDisplay(w), XtWindow(w),
 			MGR_BottomShadowGC(w),
 			MGR_TopShadowGC(w),
@@ -545,13 +562,13 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_DownWidth(w),
 			SPB_DownHeight(w),
 			SPB_DetailShadowThickness(w),
-			XmARROW_LEFT);
+			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_LEFT : XmARROW_DOWN);
 }
 
 static void
 resize(Widget w)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Resize\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Resize\n"));
 }
 
 /*
@@ -565,20 +582,20 @@ ConstraintInitialize(Widget request, Widget nw,
 {
     Widget sb = XtParent(nw);
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
 #if 0
 	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
 		if (SPBC_Numeric(nw)) {
-			DEBUGOUT(_LtDebugDebug(__FILE__, nw,
+			DEBUGOUT(_LtDebug(__FILE__, nw,
 				"ConstraintInitialize(XmNUMERIC) min %d max %d inc %d\n",
 				SPBC_Minimum(nw),
 				SPBC_Maximum(nw),
 				SPBC_Increment(nw) ));
 		}
 		else {
-			DEBUGOUT(_LtDebugDebug(__FILE__, nw,
+			DEBUGOUT(_LtDebug(__FILE__, nw,
 				"ConstraintInitialize(XmSTRING) num_values %d\n",
 				SPBC_NumValues(nw)));
 		}
@@ -597,7 +614,7 @@ ConstraintSetValues(Widget curr, Widget req, Widget nw,
 	Widget	sb = XtParent(nw);
 	Boolean	r = False;
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
 #if 0
 	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
@@ -646,28 +663,18 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 				hh = XtHeight(child);
 
 			xx += XtWidth(child) + SPB_Spacing(w);
-			DEBUGOUT(_LtDebugDebug2(__FILE__, w, child,
+			DEBUGOUT(_LtDebug2(__FILE__, w, child,
 				"PreferredSize: add width %d\n",
 				XtWidth(child)));
 	}
 
-	SPB_DownX(w) = xx;
-	SPB_DownY(w) = yy;
-	SPB_DownWidth(w) = SPB_ArrowSize(w);
-	SPB_DownHeight(w) = SPB_ArrowSize(w);
-
 	xx += SPB_DownWidth(w) + SPB_Spacing(w);
-
-	SPB_UpX(w) = xx;
-	SPB_UpY(w) = yy;
-	SPB_UpWidth(w) = SPB_ArrowSize(w);
-	SPB_UpHeight(w) = SPB_ArrowSize(w);
 	xx += SPB_UpWidth(w) + SPB_MarginWidth(w);
 
 	*wid = xx;
 	*ht = hh + 2 * SPB_MarginHeight(w);;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	"PreferredSize => %d %d (ArrowSize %d MarginWidth %d"
 	" MarginHeight %d Spacing %d)\n",
 		*wid, *ht,
@@ -679,6 +686,10 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 /*
  * Layout is primarily influenced by
  *	SPB_ArrowLayout (XmARROWS_BEGINNING, XmARROWS_END, XmARROWS_SPLIT).
+ *
+ * FIX ME
+ *	Should also take VendorShell's XmNlayoutDirection into account.
+ *	ArrowLayout XmARROWS_FLAT_BEGINNING, XmARROWS_FLAT_END missing.
  */
 static void
 Layout(Widget w, Widget instig)
@@ -687,7 +698,14 @@ Layout(Widget w, Widget instig)
 	Position	xx, yy;
 	Dimension	hh = 0;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmSpinBox Layout\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmSpinBox Layout %s\n",
+		(SPB_ArrowLayout(w) == XmARROWS_BEGINNING) ? "XmARROWS_BEGINNING" :
+		(SPB_ArrowLayout(w) == XmARROWS_END) ? "XmARROWS_END" :
+		(SPB_ArrowLayout(w) == XmARROWS_SPLIT) ? "XmARROWS_SPLIT" :
+		(SPB_ArrowLayout(w) == XmARROWS_FLAT_BEGINNING) ? "XmARROWS_FLAT_BEGINNING" :
+		(SPB_ArrowLayout(w) == XmARROWS_FLAT_END) ? "XmARROWS_FLAT_END" :
+		"??"
+	));
 
 	for (i=0; i<MGR_NumChildren(w); i++)
 	    if (XtHeight(MGR_Children(w)[i]) > hh)
@@ -716,10 +734,11 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 		break;
@@ -731,10 +750,11 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_DownX(w) = xx;
@@ -761,22 +781,84 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_UpX(w) = xx;
 	    SPB_UpY(w) = yy;
 	    SPB_UpWidth(w) = SPB_ArrowSize(w);
 	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+	    break;
+	case XmARROWS_FLAT_BEGINNING:				/* FIX ME */
+	    SPB_DownX(w) = SPB_MarginWidth(w);
+	    SPB_DownY(w) = yy;
+	    SPB_DownWidth(w) = SPB_ArrowSize(w);
+	    SPB_DownHeight(w) = SPB_ArrowSize(w);
+
+	    xx = SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_DownWidth(w);
+
+	    SPB_UpX(w) = xx;
+	    SPB_UpY(w) = yy;
+	    SPB_UpWidth(w) = SPB_ArrowSize(w);
+	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+
+	    xx += SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_UpWidth(w) + SPB_ArrowSize(w);
+
+	    for (i=0; i<MGR_NumChildren(w); i++)
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
+
+			xx += XtWidth(child) + SPB_Spacing(w);
+		}
+
+	    break;
+	case XmARROWS_FLAT_END:				/* FIX ME */
+	    xx = SPB_MarginWidth(w);
+
+	    for (i=0; i<MGR_NumChildren(w); i++)
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
+
+			xx += XtWidth(child) + SPB_Spacing(w);
+		}
+
+	    SPB_DownX(w) = xx;
+	    SPB_DownY(w) = yy;
+	    SPB_DownWidth(w) = SPB_ArrowSize(w);
+	    SPB_DownHeight(w) = SPB_ArrowSize(w);
+
+	    xx += SPB_MarginWidth(w) + SPB_ArrowSize(w) + SPB_Spacing(w);
+
+	    SPB_UpX(w) = xx;
+	    SPB_UpY(w) = yy;
+	    SPB_UpWidth(w) = SPB_ArrowSize(w);
+	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+	    break;
 	}
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	    "SpinBoxLayout: down at %d %d up at %d %d, spb size %d %d\n",
 	    SPB_DownX(w), SPB_DownY(w), SPB_UpX(w), SPB_UpY(w),
 	    XtWidth(w), XtHeight(w)));
+	 for (i=0; i<MGR_NumChildren(w); i++) {
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+			DEBUGOUT(_LtDebug2(__FILE__, w, child, "x %d y %d sz %d %d\n",
+				XtX(child), XtY(child), XtWidth(child), XtHeight(child)));
+		}
+	}
 }
 
 static XtGeometryResult
@@ -787,7 +869,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
 #define	Wants(x)	((geo.request_mode & x) == x)
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "QueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry\n"));
 
     geo = *proposed;
 
@@ -801,16 +883,16 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
     if (Wants(CWHeight) && (geo.height != answer->height))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
     if (Wants(CWWidth) && (geo.width != answer->width))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
     return XtGeometryYes;
 }
 
@@ -819,7 +901,7 @@ GeometryManager(Widget w,
 		 XtWidgetGeometry *request,
 		 XtWidgetGeometry *reply)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "GeometryManager\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "GeometryManager\n"));
 
 	/* FIX ME */
 
@@ -833,14 +915,14 @@ ChangeManaged(Widget w)
 	XtWidgetGeometry	geo;
 	XtGeometryResult	r;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "ChangeManaged\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
 
 	/* Make sure that our size is right */
 	PreferredSize(w, NULL, NULL, &geo.width, &geo.height);
 	geo.request_mode = CWWidth | CWHeight;
 
 	r = _XmMakeGeometryRequest(w, &geo);
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 		"ChangeManaged Geometry Request %s -> %s\n",
 		_LtDebugWidgetGeometry2String(&geo),
 		_LtDebugGeometryResult2String(r)));
@@ -885,9 +967,10 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 	char				*s = NULL;
 
 	tw = SPB_TextW(w);
+	spb.crossed_boundary = False;	/* Detected below */
 
 	if (tw == NULL) {
-		DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBModify: no text widget\n"));
+		DEBUGOUT(_LtDebug(__FILE__, w, "SpinBModify: no text widget\n"));
 		return;
 	}
 
@@ -908,14 +991,18 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		case XmCR_SPIN_NEXT:
 			SPBC_Position(tw)++;
 			if (SPBC_Position(tw) >
-				((SPBC_Maximum(tw) - SPBC_Minimum(tw)) / SPBC_Increment(tw)))
+				((SPBC_Maximum(tw) - SPBC_Minimum(tw)) / SPBC_Increment(tw))) {
 					SPBC_Position(tw) = 0;
+					spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_PRIOR:
 			SPBC_Position(tw)--;
-			if (SPBC_Position(tw) < 0)
-					SPBC_Position(tw) = ((SPBC_Maximum(tw) - SPBC_Minimum(tw))
-							/ SPBC_Increment(tw));
+			if (SPBC_Position(tw) < 0) {
+				SPBC_Position(tw) = ((SPBC_Maximum(tw) - SPBC_Minimum(tw))
+						/ SPBC_Increment(tw));
+				spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_FIRST:
 			SPBC_Position(tw) = SPBC_Minimum(tw);
@@ -929,7 +1016,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		s = _XmSpinBoxNumericString(tw);
 		xms = XmStringCreateSimple(s);
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"SpinBModify(NUMERIC) %d [%d,%d]\n",
 			SPBC_Position(tw), SPBC_Minimum(tw), SPBC_Maximum(tw)));
 	} else {
@@ -938,13 +1025,17 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		switch (reason) {
 		case XmCR_SPIN_NEXT:
 			SPBC_Position(tw)++;
-			if (SPBC_Position(tw) >= SPBC_NumValues(tw))
+			if (SPBC_Position(tw) >= SPBC_NumValues(tw)) {
 				SPBC_Position(tw) = 0;
+				spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_PRIOR:
 			SPBC_Position(tw)--;
-			if (SPBC_Position(tw) <= 0)
-					SPBC_Position(tw) = SPBC_NumValues(tw);
+			if (SPBC_Position(tw) <= 0) {
+				SPBC_Position(tw) = SPBC_NumValues(tw);
+				spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_FIRST:
 			SPBC_Position(tw) = 1;
@@ -957,7 +1048,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 
 		xms = XmStringCopy(SPBC_Values(tw)[SPBC_Position(tw)]);
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"SpinBModify(STRING) %d [%d,%d]\n",
 			SPBC_Position(tw), 0, SPBC_NumValues(tw)));
 	}
@@ -970,7 +1061,6 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 	spb.doit = True;
 	spb.position = SPBC_Position(tw);
 	spb.value = xms;
-	spb.crossed_boundary = False;	/* FIX ME */
 
 	XtCallCallbackList(w, SPB_ModifyVerifyCB(w), (XtPointer)&spb);
 
@@ -995,7 +1085,7 @@ _XmSpinBoxTimer(XtPointer client, XtIntervalId *timerid)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
+	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
 
 	if (SPB_UpArrowPressed(spb))
 			SpinBModify(spb, NULL, XmCR_SPIN_NEXT);
@@ -1011,7 +1101,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
 	Widget	tw;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBArm at %d %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBArm at %d %d\n",
 		event->xbutton.x, event->xbutton.y));
 
 	if ((tw = SPB_TextW(w)) == NULL)
@@ -1072,7 +1162,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBDisarm\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBDisarm\n"));
 
 	if (SPB_TimerId(w))
 		XtRemoveTimeOut(SPB_TimerId(w));
@@ -1085,37 +1175,37 @@ SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBFirst(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBFirst\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBFirst\n"));
 }
 
 static void
 SpinBLast(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBLast\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLast\n"));
 }
 
 static void
 SpinBLeft(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBLeft\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLeft\n"));
 }
 
 static void
 SpinBRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBRight\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBRight\n"));
 }
 
 static void
 SpinBNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBNext\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBNext\n"));
 }
 
 static void
 SpinBPrior(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBPrior\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBPrior\n"));
 }
 
 static void
@@ -1123,7 +1213,7 @@ _XmSpinBoxChildFocus(Widget w, XtPointer client, XtPointer call)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
 
 	SPB_TextW(spb) = w;
 }
@@ -1133,7 +1223,7 @@ InsertChild(Widget w)
 {
     Widget	spb = XtParent(w);
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->composite_class.insert_child) (w);
@@ -1143,7 +1233,7 @@ InsertChild(Widget w)
 #if 0
 		Arg		a;
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, spb, w,
+		DEBUGOUT(_LtDebug2(__FILE__, spb, w,
 			"Adding accelerators to child\n"));
 
 		XtSetArg(a, XmNtranslations,
@@ -1173,12 +1263,24 @@ _XmSpinBoxNumericString(Widget tw)
 
 	if (SPBC_DecimalPoints(tw)) {
 		sprintf(format, "%%.%df", SPBC_DecimalPoints(tw));
-		v = SPBC_Minimum(tw) + SPBC_Position(tw) * SPBC_Increment(tw);
+
+		switch (SPBC_PositionType(tw)) {
+		case XmPOSITION_INDEX:
+			v = SPBC_Minimum(tw) + SPBC_Position(tw) * SPBC_Increment(tw);
+		case XmPOSITION_VALUE:
+			v = SPBC_Position(tw);
+		}
+
 		for (i=0; i<SPBC_DecimalPoints(tw); i++)
 			v /= 10.0;
 		sprintf(s, format, v);
 	} else {
-		i = SPBC_Minimum(tw) + SPBC_Position(tw) * SPBC_Increment(tw);
+		switch (SPBC_PositionType(tw)) {
+		case XmPOSITION_INDEX:
+			i = SPBC_Minimum(tw) + SPBC_Position(tw) * SPBC_Increment(tw);
+		case XmPOSITION_VALUE:
+			i = SPBC_Position(tw);
+		}
 		sprintf(s, "%d", i);
 	}
 
@@ -1193,7 +1295,7 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 	XmString	xms;
 	XmAccessTextualTrait	trait;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
 
 	if (spb == NULL || t == NULL)
 		return;
@@ -1237,19 +1339,19 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 static void
 SpinBoxEnter(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBoxEnter\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxEnter\n"));
 }
 
 static void
 SpinBoxFocusIn(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBoxFocusIn\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusIn\n"));
 }
 
 static void
 SpinBoxFocusOut(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "SpinBoxFocusOut\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusOut\n"));
 }
 
 /*
@@ -1261,7 +1363,7 @@ _XmSPBTraitChangeMoveCB(Widget nav,
 			XtPointer closure,
 			Boolean setUnset)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, nav,
+	DEBUGOUT(_LtDebug(__FILE__, nav,
 		"_XmSPBTraitChangeMoveCB (%s)\n",
 		setUnset ? "set" : "unset"));
 
@@ -1276,7 +1378,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 {
 	Widget	tw;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
 
 	tw = SPB_TextW(nav);
 	if (tw == NULL)
@@ -1305,7 +1407,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 static int
 _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
 	return 0;
 }
 
@@ -1315,7 +1417,7 @@ _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 static void
 _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
 
 	/*
 	 * This gets called when a navigator (e.g. Notebook) that we're
@@ -1326,22 +1428,82 @@ _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 }
 
 
+/*
+ * An excerpt from http://www.motifdeveloper.com/tips/tip13.html :
+ *
+ * int XmSpinBoxValidatePosition(Widget text, int *position_value)
+ *
+ * XmSpinBoxValidatePosition() checks that the text child of an XmSpinBox has a valid position and
+ * value. If the current position is valid, it is returned into the address specified by
+ * position_value. The function also returns an integer representing the status of the check,
+ * as follows: 
+ *	XmCURRENT_VALUE 
+ *		This is returned if the XmNspinBoxChildType of text is not XmNUMERIC. 
+ *	XmMINIMUM_VALUE 
+ *		The current XmNposition resource of text is less than the XmNminimumValue
+ *		resource of the widget. 
+ *	XmMAXIMUM_VALUE 
+ *		The current XmNposition resource of text is greater than the XmNmaximumValue
+ *		resource of the widget. 
+ *	XmINCREMENT_VALUE 
+ *		The current XmNposition resource of text falls between the minimum and maximum
+ *		bounds set for the widget. In addition, the position should not fall on an
+ *		increment boundary. That is, it is not defined by: 
+ *			minimum + (n * increment) 
+ *		The nearest value (not less than the current value) which does fall on an
+ *		increment is calculated, and returned in the position_value parameter of the
+ *		function. 
+ *	XmNVALID_VALUE 
+ *		The current XmNposition resource of text falls between the minimum and maximum
+ *		bounds set for the widget. In addition, unlike the case for XmINCREMENT_VALUE,
+ *		the position does fall on an increment boundary. 
+ * Note that this routine does not modify the current position associated with text. 
+ */
 extern int
-XmSpinBoxValidatePosition(Widget textfield,
-                          int *position)
+XmSpinBoxValidatePosition(Widget t, int *position)
 {
-   int oldpos;
+	int			intval, i;
+	XmAccessTextualTrait	trait;
+	char			*s;
+	double			d;
 
-   if (SPBC_Numeric(textfield)) {
-	oldpos = SPBC_Position(textfield);
-	*position = oldpos;
-        _XmWarning(NULL, "XmSpinBoxValidatePosition(): not yet implemented!");
-        return XmCURRENT_VALUE;
-   }
-   else {
-        /* non-numeric */
-	oldpos = SPBC_Position(textfield);
-	*position = oldpos;
-	return XmCURRENT_VALUE;
-   }
+	if (! SPBC_Numeric(t)) {
+		return XmCURRENT_VALUE;
+	}
+
+	trait = (XmAccessTextualTrait)XmeTraitGet((XtPointer)XtClass(t), XmQTaccessTextual);
+	if (trait == NULL) {
+		_XmError(t, "_XmSpinBoxShowValue: no trait XmQTaccessTextual\n");
+		return XmCURRENT_VALUE;
+	} else if (trait->version != 0) {
+		_XmWarning(t, "Version of trait record is %d not %d\n", trait->version, 0);
+	}
+
+	s = trait->getValue(t, XmFORMAT_WCS);
+	if (s == 0) {
+		_XmWarning(t, "XmSpinBoxValidatePosition TraitGetValue -> NULL : this shouldn't happen\n");
+		return XmCURRENT_VALUE;	/* Maybe the app doesn't crash if we do this */
+	}
+	d = atof(s);
+	for (i=0; i<SPBC_DecimalPoints(t); i++)
+		d /= 10;
+	intval = d;
+
+	if (intval < SPBC_Minimum(t))
+		return XmMINIMUM_VALUE;
+	if (intval > SPBC_Maximum(t))
+		return XmMAXIMUM_VALUE;
+
+	/* Calculate the nearest greater value that does fall on an increment */
+	d = intval;
+	d = (d - SPBC_Minimum(t)) / SPBC_Increment(t);
+	i = d;
+	if (i != d)
+		i++;
+
+	*position = SPBC_Minimum(t) + i * SPBC_Increment(t);
+
+	if (i == d)
+		return XmVALID_VALUE;
+	return XmINCREMENT_VALUE;
 }
