@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.37 2001/05/21 08:36:52 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.40 2002/03/28 23:59:33 amai Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
- * Copyright (C) 1998-2001 LessTif Development Team
+ * Copyright (C) 1998-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.37 2001/05/21 08:36:52 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.40 2002/03/28 23:59:33 amai Exp $";
 
 /*
  * This is a widget whose main purpose is to do geometry management for its
@@ -576,7 +576,7 @@ _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 				/* Move out of sight */
 				_XmMoveObject(c, -10000, -10000);	/* FIX ME */
 
-				DEBUGOUT(_LtDebugDebug2(__FILE__, nb, c,
+				DEBUGOUT(_LtDebug2(__FILE__, nb, c,
 					"Move child out of sight\n"));
 			}
 		}
@@ -593,7 +593,7 @@ _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 			/* h */	NB_PageHeight(nb),
 			/* bw */	XtBorderWidth(child));
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, child, "Move child to %d %d sz %d %d\n",
+		DEBUGOUT(_LtDebug2(__FILE__, nb, child, "Move child to %d %d sz %d %d\n",
 			/* x */	NB_BindingWidth(nb) + NB_MarginWidth(nb),
 			/* y */	0,
 			/* w */	NB_PageWidth(nb),
@@ -611,7 +611,7 @@ _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 			/* h */	NB_StatusHeight(nb),
 			/* bw */	XtBorderWidth(child));
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, status, "Move status to %d %d sz %d %d\n",
+		DEBUGOUT(_LtDebug2(__FILE__, nb, status, "Move status to %d %d sz %d %d\n",
 			/* x */	NB_BindingWidth(nb) + NB_MarginWidth(nb),
 			/* y */	NB_PageHeight(nb),
 			/* w */	NB_StatusWidth(nb),
@@ -645,21 +645,21 @@ _XmNotebookShowPage(Widget w, int page, int reason, XEvent *evp)
 	    if (NBC_ChildType(c) == XmPAGE && NBC_PageNumber(c) == page) {
 		cl = c;
 #if 0
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, cl, "page child found\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, cl, "page child found\n"));
 #endif
 	    }
 
 	    if (NBC_ChildType(c) == XmSTATUS_AREA && NBC_PageNumber(c) == page) {
 		status = c;
 #if 0
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, status, "Status child found\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, status, "Status child found\n"));
 #endif
 	    }
 	}
 
 	if (cl == NULL) {
 		/* What to do here ?? FIX ME */
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"_XmNotebookShowPage(%d) : not found\n", page));
 		return;
 	}
@@ -682,7 +682,7 @@ _XmNotebookShowPage(Widget w, int page, int reason, XEvent *evp)
 	/*
 	 * Show the XmPAGE widget and the STATUS_AREA.
 	 */
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, cl,
+	DEBUGOUT(_LtDebug2(__FILE__, w, cl,
 		"_XmNotebookShowPage nr %d\n", page));
 	_XmNotebookShowChild(w, cl, status);
 
@@ -713,7 +713,7 @@ Initialize(Widget request, Widget nw,
 {
     Arg	*l, al[1];
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, nw,
+    DEBUGOUT(_LtDebug(__FILE__, nw,
 		      "Notebook initialize: w/h %d %d\n",
 		      XtWidth(nw), XtHeight(nw)));
 
@@ -801,7 +801,7 @@ Initialize(Widget request, Widget nw,
 static void
 destroy(Widget w)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Destroy\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
 
 	XFreeColors(XtDisplay(w),
 		DefaultColormapOfScreen(XtScreenOfObject(w)),
@@ -817,7 +817,7 @@ SetValues(Widget old, Widget request, Widget nw,
     Boolean	need_refresh = False,
 		need_layout = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, nw, "SetValues\n"));
+    DEBUGOUT(_LtDebug(__FILE__, nw, "SetValues\n"));
 
 #define	NE(x)	(x(nw) != x(old))
 
@@ -848,7 +848,7 @@ SetValues(Widget old, Widget request, Widget nw,
     if (NE(NB_FirstPageNumber) || NE(NB_LastPageNumber)) {
 	XmNavigatorTrait		t;
 	XmNavigatorDataRec		nd;
-	XmTwoDIntRec			ndmin, ndmax, ndval;
+	XmTwoDIntRec			ndmin, ndmax;
 	/*
 	 * Use trait method to update XmPAGE_SCROLLER
 	 */
@@ -970,7 +970,7 @@ expose(Widget w, XEvent *event, Region region)
     if (! XtWindow(w))
 	return;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Expose\n"));
 
     /* Display back page first */
     draw_back_pages(w);
@@ -988,7 +988,7 @@ expose(Widget w, XEvent *event, Region region)
 static void
 resize(Widget w)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Resize\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Resize\n"));
 	if (XtIsRealized(w))
 		XClearArea(XtDisplay(w), XtWindow(w), 0, 0, 0, 0, False);
 	Layout(w);
@@ -1002,7 +1002,7 @@ _XmNBTabCallback(Widget w, XtPointer client, XtPointer call)
 	int			r = (int)(long)client;
 	XmAnyCallbackStruct	*cbp = (XmAnyCallbackStruct *)call;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmNBTabCallback\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBTabCallback\n"));
 
 	_XmNotebookShowPage(XtParent(w), NBC_PageNumber(w),
 		/* reason */	r,
@@ -1016,7 +1016,7 @@ _XmNBPageScrollerCallback(Widget w, XtPointer client, XtPointer call)
 	int			r, page, oldpage;
 	XmSpinBoxCallbackStruct	*cbp = (XmSpinBoxCallbackStruct *)call;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmNBPageScrollerCallback\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBPageScrollerCallback\n"));
 
 	/*
 	 * Figure out whether we increment or decrement,
@@ -1108,45 +1108,45 @@ ConstraintInitialize(Widget request, Widget nw,
     Widget nb = XtParent(nw);
     XtPointer	t;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "ConstraintInitialize\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "ConstraintInitialize\n"));
 
     if (NBC_ChildType(nw) == XmNONE) {
 	/* Assign a default child type. */
 	if (XmeTraitGet((XtPointer)XtClass(nw), XmQTaccessTextual) != NULL) {
 		NBC_ChildType(nw) = XmSTATUS_AREA;
 		NBC_Active(nw) = False;
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
 	} else if (XmeTraitGet((XtPointer)XtClass(nw), XmQTactivatable) != NULL) {
 		NBC_ChildType(nw) = XmMAJOR_TAB;
 		NBC_Active(nw) = False;
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
 	} else if (XmeTraitGet((XtPointer)XtClass(nw), XmQTnavigator) != NULL) {
 		NBC_ChildType(nw) = XmPAGE_SCROLLER;
 		NBC_Active(nw) = False;
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
 		NB_Scroller(nb) = nw;
 #ifdef	TRAIT_WORKAROUND
 	} else if (XtIsSubclass(nw, xmTextWidgetClass)
 			|| XtIsSubclass(nw, xmTextFieldWidgetClass)) {
 		NBC_ChildType(nw) = XmSTATUS_AREA;
 		NBC_Active(nw) = False;
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
 	} else if (XtIsSubclass(nw, xmPushButtonWidgetClass)
 			|| XtIsSubclass(nw, xmPushButtonGadgetClass)
 			|| XtIsSubclass(nw, xmArrowButtonWidgetClass)
 			|| XtIsSubclass(nw, xmArrowButtonGadgetClass)) {
 		NBC_ChildType(nw) = XmMAJOR_TAB;
 		NBC_Active(nw) = False;
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
 	} else if (XtIsSubclass(nw, xmScrollBarWidgetClass)) {
 		NBC_ChildType(nw) = XmPAGE_SCROLLER;
 		NBC_Active(nw) = False;
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
 		NB_Scroller(nb) = nw;
 #endif
 	} else {
 		NBC_ChildType(nw) = XmPAGE;
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "is a XmPAGE\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmPAGE\n"));
 	}
     }
 
@@ -1209,7 +1209,7 @@ ConstraintInitialize(Widget request, Widget nw,
 
 	NB_LastAllocNum(nb) = NBC_PageNumber(nw);
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "Child has page no %d\n",
+	DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "Child has page no %d\n",
 		NBC_PageNumber(nw)));
 
 	if (XtWidth(nw) > NB_PageWidth(nb))
@@ -1257,7 +1257,7 @@ ConstraintSetValues(Widget current, Widget request, Widget nw,
 		need_layout = True;
 	Widget	nb = XtParent(nw);
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, nb, nw, "ConstraintSetValues\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "ConstraintSetValues\n"));
 
 	/* This resource cannot be changed after creation */
 	if (NBC_ChildType(nw) != NBC_ChildType(current))
@@ -1308,7 +1308,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			continue;
 
 		if (NBC_ChildType(child) == XmPAGE) {
-		    DEBUGOUT(_LtDebugDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize PAGE size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1326,7 +1326,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 				    ht = XtHeight(child);
 			}
 		} else if (NBC_ChildType(child) == XmMAJOR_TAB) {
-		    DEBUGOUT(_LtDebugDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize MAJOR TAB size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1346,7 +1346,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			    hortabwid = XtWidth(child);
 		    }
 		} else if (NBC_ChildType(child) == XmMINOR_TAB) {
-		    DEBUGOUT(_LtDebugDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize MINOR TAB size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1366,7 +1366,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			    verttabwid = XtWidth(child);
 		    }
 		} else if (NBC_ChildType(child) == XmSTATUS_AREA) {
-		    DEBUGOUT(_LtDebugDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize STATUS AREA size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1375,7 +1375,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			if (saht < XtHeight(child))
 				saht = XtHeight(child);
 		} else if (NBC_ChildType(child) == XmPAGE_SCROLLER) {
-		    DEBUGOUT(_LtDebugDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize PAGE SCROLLER size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1399,7 +1399,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 	NB_StatusWidth(nb) = sawid;
 	NB_StatusHeight(nb) = saht;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, nb,
+	DEBUGOUT(_LtDebug(__FILE__, nb,
 		"PreferredSize: %d major tabs (%d x %d), %d minor tabs (%d x %d)\n",
 		nverttab, verttabwid, verttabht,
 		nhortab, hortabwid, hortabht));
@@ -1411,7 +1411,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			+ 2 * NB_MarginHeight(nb);
 		vw = verttabwid + NB_MarginWidth(nb);
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, nb,
+		DEBUGOUT(_LtDebug(__FILE__, nb,
 			"PreferredSize: add %d %d for column of tabs\n",
 			vw, vh));
 
@@ -1424,7 +1424,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			+ 2 * NB_MarginHeight(nb);
 		hw = hortabwid + NB_MarginWidth(nb);
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, nb,
+		DEBUGOUT(_LtDebug(__FILE__, nb,
 			"PreferredSize: add %d %d for row of tabs\n",
 			hw, hh));
 
@@ -1448,7 +1448,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 		NB_ScrollerWidth(nb) = XtWidth(NB_Scroller(nb));
 		NB_ScrollerHeight(nb) = XtHeight(NB_Scroller(nb));
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, nb, NB_Scroller(nb),
+		DEBUGOUT(_LtDebug2(__FILE__, nb, NB_Scroller(nb),
 			"Page Scroller adds %d + 2 * %d to height\n",
 			XtHeight(NB_Scroller(nb)), NB_MarginHeight(nb)));
 	}
@@ -1466,7 +1466,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 	wid += NB_BindingWidth(nb) + NB_MarginWidth(nb) + NB_BackPageSize(nb);
 	ht += NB_BackPageSize(nb);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, nb, "PreferredSize => %d %d\n", wid, ht));
+	DEBUGOUT(_LtDebug(__FILE__, nb, "PreferredSize => %d %d\n", wid, ht));
 
 	if (widp) *widp = wid;
 	if (htp) *htp = ht;
@@ -1480,7 +1480,7 @@ Layout(Widget w )
 	Position	majx, majy;
 	Position	minx, miny;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Layout (nb wid %d ht %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "Layout (nb wid %d ht %d)\n",
 		XtWidth(w), XtHeight(w)));
 
 #ifdef LARGE_PAGE
@@ -1497,7 +1497,7 @@ Layout(Widget w )
 	    else
 		NB_PageHeight(w) -= NB_BindingWidth(w);
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Layout: set page size to %d %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Layout: set page size to %d %d\n",
 		NB_PageWidth(w), NB_PageHeight(w)));
 	}
 
@@ -1520,7 +1520,7 @@ Layout(Widget w )
 		_XmMoveObject(child, majx, majy);
 		majy += XtHeight(child) + NB_MajorSpacing(w);
 	    } else if (NBC_ChildType(child) == XmMINOR_TAB) {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, child, "Layout: XmMINOR_TAB\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, child, "Layout: XmMINOR_TAB\n"));
 		_XmMoveObject(child, minx, miny);
 		minx += XtWidth(child) + NB_MinorSpacing(w);
 /* HERE */
@@ -1529,7 +1529,7 @@ Layout(Widget w )
 			NB_BindingWidth(w) + NB_MarginWidth(w) * 2 + NB_StatusWidth(w),
 			NB_PageHeight(w) + NB_MarginHeight(w));
 	    } else if (NBC_ChildType(child) == XmSTATUS_AREA) {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, child, "Layout: XmSTATUS_AREA\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, child, "Layout: XmSTATUS_AREA\n"));
 	    } else {
 		/* XmPAGE treated elsewhere */
 	    }
@@ -1540,9 +1540,9 @@ Layout(Widget w )
 static void
 InsertChild(Widget w)
 {
-	Widget	nb = XtParent(w);
+	/* Widget	nb = XtParent(w); */
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, nb, w, "InsertChild\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w, "InsertChild\n"));
 
 #define	superclass	(&xmManagerClassRec)
 	(*superclass->composite_class.insert_child)(w);
@@ -1553,9 +1553,9 @@ InsertChild(Widget w)
 static void
 DeleteChild(Widget w)
 {
-	Widget	nb = XtParent(w);
+	/* Widget	nb = XtParent(w); */
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, nb, w, "DeleteChild\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w, "DeleteChild\n"));
 
 #define	superclass	(&xmManagerClassRec)
 	(*superclass->composite_class.delete_child)(w);
@@ -1571,7 +1571,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
 #define	Wants(x)	((geo.request_mode & x) == x)
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "QueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry\n"));
 
     geo = *proposed;
 
@@ -1608,7 +1608,7 @@ GeometryManager(Widget w,
 	XtWidgetGeometry	req, preq;
 #endif
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(w), w, "GeometryManager\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w, "GeometryManager\n"));
 
 	return XtGeometryNo;
 }
@@ -1623,21 +1623,21 @@ ChangeManaged(Widget w)
 	(void)MajorTabsActive(w);
 	Layout(w);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "ChangeManaged\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
 }
 
 
 static void
 TraverseTab(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "TraverseTab\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "TraverseTab\n"));
 }
 
 
 static void
 _XmNBDefaultLastPageNumber(Widget w, int offset, XrmValue *val)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmNBDefaultLastPageNumber\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBDefaultLastPageNumber\n"));
 
 	NB_DynamicLastPageNum(w) = True;
 	NB_LastPageNumber(w) = 1;
@@ -1723,7 +1723,7 @@ _XmNBChangeGC(Widget w)
 static void
 Realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Realize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->core_class.realize) (w, value_mask, attributes);
@@ -1735,14 +1735,14 @@ Realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
     Layout(w);
     _XmNotebookShowPage(w, 1, 0, NULL);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Realize (end)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize (end)\n"));
 }
 
 
 static void
 _XmNBFrameBackgroundDefault(Widget w, int offset, XrmValue *val)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmNBFrameBackgroundDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBFrameBackgroundDefault\n"));
 
     /*
      * The current solution is to copy the overall background colour
@@ -1781,7 +1781,7 @@ _XmNBBackPageBackgroundDefault(Widget w, int offset, XrmValue *val)
 	back.pixel = color.pixel;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 	"_XmNBBackPageBackgroundDefault %d (%d,%d,%d) -> %d (%d,%d,%d)\n",
 	color.pixel, color.red, color.green, color.blue,
 	back.pixel, back.red, back.green, back.blue));
@@ -1794,7 +1794,7 @@ _XmNBBackPageBackgroundDefault(Widget w, int offset, XrmValue *val)
 static void
 _XmNBTraitInit(Widget sfw, XtCallbackProc moveCB, Widget sw)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, sfw, "_XmNBTraitInit\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitInit\n"));
 }
 
 
@@ -1804,7 +1804,7 @@ _XmNBTraitGetInfo(Widget sfw,
 		Widget **nav_list,
 		Cardinal *num_nav_list)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, sfw, "_XmNBTraitGetInfo\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitGetInfo\n"));
 
 	/* FIX ME unimplemented */
 	return False;
@@ -1814,14 +1814,14 @@ _XmNBTraitGetInfo(Widget sfw,
 static void
 _XmNBTraitAddNavigator(Widget sfw, Widget nw, Mask dimMask)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, sfw, "_XmNBTraitAddNavigator\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitAddNavigator\n"));
 }
 
 
 static void
 _XmNBTraitRemoveNavigator(Widget sfw, Widget nw)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, sfw, "_XmNBTraitRemoveNavigator\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitRemoveNavigator\n"));
 }
 
 
