@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ArrowB.c,v 1.36 2001/05/21 08:36:51 amai Exp $
+ * $Id: ArrowB.c,v 1.38 2002/04/12 21:07:02 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright (C) 1995-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ArrowB.c,v 1.36 2001/05/21 08:36:51 amai Exp $";
+static const char rcsid[] = "$Id: ArrowB.c,v 1.38 2002/04/12 21:07:02 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -33,6 +33,11 @@ static const char rcsid[] = "$Id: ArrowB.c,v 1.36 2001/05/21 08:36:51 amai Exp $
 #include <Xm/RepType.h>
 #include <Xm/TransltnsP.h>
 
+#if XmVERSION > 1
+#include <Xm/TraitP.h>
+#include <Xm/ActivatableT.h>
+#endif
+
 #include <XmI/DebugUtil.h>
 
 /*
@@ -41,9 +46,6 @@ static const char rcsid[] = "$Id: ArrowB.c,v 1.36 2001/05/21 08:36:51 amai Exp $
  * Try to add trait stuff by #ifdeffing it.
  */
 #if XmVERSION > 1
-#include <Xm/TraitP.h>
-#include <Xm/ActivatableT.h>
-
 void _XmArrowB_TraitAddCallback(Widget, XtCallbackProc, XtPointer, Boolean);
 
 static XmActivatableTraitRec _XmArrowBTraitRec = {
@@ -66,20 +68,15 @@ static XmActivatableTraitRec _XmArrowBTraitRec = {
 static void class_initialize(void);
 #endif
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void expose(Widget w, XEvent *event, Region region);
-
 #if 0
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *proposed,
 				       XtWidgetGeometry *answer);
 #endif
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 
@@ -351,7 +348,7 @@ set_values(Widget old, Widget request, Widget new_w,
 			     AB_MultiClick(new_w), new_w))
 	AB_MultiClick(new_w) = AB_MultiClick(old);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "ArrowB set_values\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ArrowB set_values\n"));
 
     if (AB_Direction(old) != AB_Direction(new_w) ||
 #if XmVERSION > 1
@@ -471,7 +468,7 @@ Arm(Widget w, XEvent *event, String *params, Cardinal *num_params)
     int margin;
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Arm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Arm\n"));
 
     if (!AB_Armed(w))
     {
@@ -520,7 +517,7 @@ Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmArrowButtonCallbackStruct cbs;
     XButtonEvent *ev = (XButtonEvent *)event;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Activate 000\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate 000\n"));
 
     if (XtIsRealized(w))
     {
@@ -565,7 +562,7 @@ Disarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
     int margin;
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Disarm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Disarm\n"));
 
     if (AB_Armed(w))
     {
@@ -606,7 +603,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
     int margin;
     Widget w = (Widget)data;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     AB_Timer(w) = 0;
 
@@ -648,7 +645,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
 
     /* Arm, Activate, and Disarm now, but draw the disarmed state later */
 
@@ -690,7 +687,7 @@ EnterWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     int margin = Prim_ShadowThickness(w) + Prim_HighlightThickness(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "EnterWindow\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "EnterWindow\n"));
 
     if (AB_Armed(w))
     {
@@ -714,7 +711,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     int margin = Prim_ShadowThickness(w) + Prim_HighlightThickness(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "LeaveWindow\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LeaveWindow\n"));
 
     if (AB_Armed(w))
     {
@@ -736,7 +733,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 MultiArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MultiArm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MultiArm\n"));
 
     if (AB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
@@ -751,7 +748,7 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XButtonEvent *ev = (XButtonEvent *)event;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "PushB: MultiClick\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PushB: MultiClick\n"));
 
     if (AB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
