@@ -1,6 +1,6 @@
 /**
  *
- * $Id: BaseClass.c,v 1.24 2001/05/17 13:04:49 amai Exp $
+ * $Id: BaseClass.c,v 1.26 2001/08/21 14:11:36 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BaseClass.c,v 1.24 2001/05/17 13:04:49 amai Exp $";
+static const char rcsid[] = "$Id: BaseClass.c,v 1.26 2001/08/21 14:11:36 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -660,12 +660,12 @@ static XtGeometryHandler GeometryWrappers[] =
 static int
 RealizeDepth(WidgetClass MyWc)
 {
-    int Depth = 0;
+    int depth = 0;
     WidgetClass wc = MyWc;
 
     while ((wc != NULL) && (wc != (WidgetClass)vendorShellWidgetClass))
     {
-	Depth++;
+	depth++;
 	wc = wc->core_class.superclass;
     }
 
@@ -678,17 +678,17 @@ RealizeDepth(WidgetClass MyWc)
 		 MyWc->core_class.class_name);
     }
 
-    if (Depth > MAX_REALIZE_WRAPPER_DEPTH)
+    if (depth > MAX_REALIZE_WRAPPER_DEPTH)
     {
 	_XmError(NULL,
 		 "SORRY: widget class \"%s\" is subclassed too deep from\n"
 		 "the vendorShellWidgetClass. Current depth is %i whereas the\n"
 		 "allowed maximum depth is %d.",
 		 MyWc->core_class.class_name,
-		 Depth, MAX_REALIZE_WRAPPER_DEPTH);
+		 depth, MAX_REALIZE_WRAPPER_DEPTH);
     }
 
-    return Depth;
+    return depth;
 }
 
 
@@ -699,12 +699,12 @@ RealizeDepth(WidgetClass MyWc)
 static int
 ResizeDepth(WidgetClass MyWc)
 {
-    int Depth = 0;
+    int depth = 0;
     WidgetClass wc = MyWc;
 
     while ((wc != NULL) && (wc != (WidgetClass)rectObjClass))
     {
-	Depth++;
+	depth++;
 	wc = wc->core_class.superclass;
     }
 
@@ -720,17 +720,17 @@ ResizeDepth(WidgetClass MyWc)
 		 MyWc->core_class.class_name);
     }
 
-    if (Depth >MAX_RESIZE_WRAPPER_DEPTH)
+    if (depth >MAX_RESIZE_WRAPPER_DEPTH)
     {
 	_XmError(NULL,
 		 "SORRY: widget class \"%s\" is subclassed too deep from\n"
 		 "the rectObject widget class. Current depth is %i whereas\n"
 		 "the allowed maximum depth is %d.",
 		 MyWc->core_class.class_name,
-		 Depth, MAX_RESIZE_WRAPPER_DEPTH);
+		 depth, MAX_RESIZE_WRAPPER_DEPTH);
     }
 
-    return Depth;
+    return depth;
 }
 
 
@@ -740,12 +740,12 @@ ResizeDepth(WidgetClass MyWc)
 static int
 GeomDepth(WidgetClass MyWc)
 {
-    int Depth = 0;
+    int depth = 0;
     WidgetClass wc = MyWc;
 
     while ((wc != NULL) && (wc != (WidgetClass)rectObjClass))
     {
-	Depth++;
+	depth++;
 	wc = wc->core_class.superclass;
     }
 
@@ -758,17 +758,17 @@ GeomDepth(WidgetClass MyWc)
 		 MyWc->core_class.class_name);
     }
 
-    if (Depth >MAX_GEOM_WRAPPER_DEPTH)
+    if (depth >MAX_GEOM_WRAPPER_DEPTH)
     {
 	_XmError(NULL,
 		 "SORRY: widget class \"%s\" is subclassed too deep from\n"
 		 "the rectObject widget class. Current depth is %i whereas\n"
 		 "the allowed maximum depth is %d.",
 		 MyWc->core_class.class_name,
-		 Depth, MAX_GEOM_WRAPPER_DEPTH);
+		 depth, MAX_GEOM_WRAPPER_DEPTH);
     }
 
-    return Depth;
+    return depth;
 }
 
 
@@ -976,12 +976,12 @@ BaseClassPartInitialize(WidgetClass wc)
 	sext = _XmGetBaseClassExtPtr(sclass, XmQmotif);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "BaseClassPartInit on %s with %s base ext rec.\n",
 		      wc->core_class.class_name,
 		      (ext && *ext) ? "a" : "NO!"));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "BaseClassPartInit: sclass %s with %s base ext rec.\n",
 		      wc->core_class.superclass->core_class.class_name,
 		      (sext && *sext) ? "a" : "NO!"));
@@ -1047,7 +1047,7 @@ BaseClassPartInitialize(WidgetClass wc)
 	 * to indicate that this class had no base extension...
 	 */
 	XmBaseClassExt p;
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "BaseClassPartInit(): %s got bce record on the fly\n",
 			  wc->core_class.class_name));
 
@@ -1309,7 +1309,7 @@ GeometryHandlerWrapper(Widget w, XtWidgetGeometry *request,
     static Boolean recurse = False;
     XtGeometryResult ret;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "GeometryHandlerWrapper(%d) : request %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "GeometryHandlerWrapper(%d) : request %s\n",
 		      IntentedWrapperDepth, _LtDebugWidgetGeometry2String(request)));
 
     WindUp = GeomDepth(wc) - IntentedWrapperDepth;
@@ -1951,7 +1951,7 @@ XmGetSecondaryResourceData(WidgetClass w_class,
 {
     XmBaseClassExt *bce = NULL;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmGetSecondaryResourceData() called on %s.\n",
 		      w_class->core_class.class_name));
 
