@@ -1,9 +1,9 @@
 /**
  *
- * $Id: CascadeBG.c,v 1.144 2001/05/20 17:49:38 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/CascadeBG.c,v 1.148 2002/11/02 07:28:47 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CascadeBG.c,v 1.144 2001/05/20 17:49:38 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/CascadeBG.c,v 1.148 2002/11/02 07:28:47 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -274,6 +274,9 @@ static XmGadgetClassExtRec _XmCascadeBGGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ XmInheritBaselineProc,
     /* display_rect_proc         */ XmInheritDisplayRectProc,
+#if XmVERSION >= 2
+    /* margins_proc              */ XmInheritMarginsProc,
+#endif
 };
 
 XmCascadeButtonGadgetClassRec xmCascadeButtonGadgetClassRec = {
@@ -350,7 +353,7 @@ secondary_object_create(Widget request, Widget new_w,
     XmWidgetExtData ed;
     Cardinal size;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "CascadeButtonGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -450,11 +453,21 @@ _XmArrowPixmapCacheDelete(XtPointer data)
 static Dimension
 default_font_height(XmFontList fl)
 {
-    XFontStruct *font;
+	XFontStruct *font;
+	Dimension	fh;
 
-    return _XmFontListGetDefaultFont(fl, &font)
-	? font->ascent + font->descent
-	: 0;
+#ifdef	USE_XFT
+	if (fl->renditions[0]->type == XmFONT_IS_XFT) {
+		fh = fl->renditions[0]->xft_font->height;
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "DefaultFontHeight -> %d\n", fh));
+		return fh;
+	}
+#endif
+	fh = _XmFontListGetDefaultFont(fl, &font)
+		? font->ascent + font->descent
+		: 0;
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "DefaultFontHeight -> %d\n", fh));
+	return fh;
 }
 
 /* Assumes that the existing pixmaps are freed */
@@ -622,7 +635,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "CascadeBG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "CascadeBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -983,7 +996,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "set_values()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "set_values()\n"));
 
     if (CBG_MapDelay(new_w) < 0)
     {
@@ -1262,7 +1275,7 @@ expose(Widget w,
        XEvent *event,
        Region region)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "expose() Armed(%d) type %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "expose() Armed(%d) type %s\n",
 		      CBG_IsArmed(w), _LtDebugMenuType2String(LabG_MenuType(w))));
 
     draw_cascade(w);
@@ -1286,12 +1299,12 @@ DoSelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
 Boolean validButton;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:DoSelect(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:DoSelect(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
 	));
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:DoSelect(%d)\n\t%s posted mine %s %s\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:DoSelect(%d)\n\t%s posted mine %s %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none",
@@ -1352,12 +1365,12 @@ MenuBarSelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     Boolean validButton;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
 	));
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:MenuBarSelect(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
@@ -1413,8 +1426,8 @@ MenuBarSelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 ArmAndPost(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmAndPost(): %p %p\n", w, CBG_Submenu(w)));
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:ArmAndPost(%d)\n\t%s posted mine %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndPost(): %p %p\n", w, CBG_Submenu(w)));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ArmAndPost(%d)\n\t%s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "none"
@@ -1425,7 +1438,7 @@ ArmAndPost(Widget w, XEvent *event, String *params, Cardinal *num_params)
 #if 0
     if (!RC_IsArmed(CBG_Submenu(w)))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "MENU_ARM\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "MENU_ARM\n"));
 
 	RCClass_MenuProcs(XtClass(XtParent(w)))(XmMENU_ARM, XtParent(w), NULL);
     }
@@ -1444,14 +1457,14 @@ ArmAndPost(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 MenuBarEnter(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
 	_XmGetInDragMode(w) ? "Dragging" : "Not Dragging",
 	_LtDebugRcType2String(LabG_MenuType(w)),
 	RC_IsArmed(XtParent(w)) ? "Armed" : "Not Armed",
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "nothing",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "nothing"
 	));
-    DEBUGOUT(_LtDebugDebug("MENU", w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
+    DEBUGOUT(_LtDebug("MENU", w, "MenuBarEnter\n\t%s %s %s %s posted posting %s\n",
 	_XmGetInDragMode(w) ? "Dragging" : "Not Dragging",
 	_LtDebugRcType2String(LabG_MenuType(w)),
 	RC_IsArmed(XtParent(w)) ? "Armed" : "Not Armed",
@@ -1533,7 +1546,7 @@ StartDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Boolean validButton;
     Boolean poppedUp;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "StartDrag()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "StartDrag()\n"));
 
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
@@ -1551,7 +1564,7 @@ StartDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     /* Was it the right button? */
     RC_MenuButton(w, event, &validButton);
 
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:StartDrag(%d) - %s posted mine %s\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:StartDrag(%d) - %s posted mine %s\n",
 	__FILE__, __LINE__,
 	RC_PopupPosted(XtParent(w)) ? XtName(RC_PopupPosted(XtParent(w))) : "None",
 	CBG_Submenu(w) ? XtName(CBG_Submenu(w)) : "None"
@@ -1594,7 +1607,7 @@ CascadePopupHandler(XtPointer clientData, XtIntervalId *id)
 
     CBG_Timer(w) = 0;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "CascadePopupHandler()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "CascadePopupHandler()\n"));
 
     _XmCascadingPopup(w, NULL, True);	/* FIX ME: NULL? */
 }
@@ -1603,7 +1616,7 @@ CascadePopupHandler(XtPointer clientData, XtIntervalId *id)
 static void
 DelayedArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DelayedArm()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DelayedArm()\n"));
 
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
@@ -1634,7 +1647,7 @@ CheckDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
     int y = ((XLeaveWindowEvent *)event)->y_root;
     Widget subpane;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "CheckDisarm() - %i %i %i\n", x, y, XtHeight(w)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "CheckDisarm() - %i %i %i\n", x, y, XtHeight(w)));
 
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
@@ -1690,7 +1703,7 @@ Help(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
 
     MGR_ActiveChild(XtParent(w)) = w;
     if (LabG_MenuType(w) == XmMENU_BAR)
@@ -1711,7 +1724,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 	if (CBG_Submenu(w) && !RC_IsArmed(CBG_Submenu(w)))
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MENU_ARM\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "MENU_ARM\n"));
 
 	    RCClass_MenuProcs(XtClass(XtParent(w)))(XmMENU_ARM,
 						    XtParent(w), NULL);
@@ -1848,7 +1861,7 @@ MenuProcEntry(int proc, Widget w,...)
 void
 XmCascadeButtonGadgetHighlight(Widget w, Boolean highlight)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "XmCascadeButtonGadgetHighlight(hl %d, armed %d,"
 		      " apm 0x%X, cpm 0x%X), %s, geo %d %d %dx%d\n",
 		      highlight,
