@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.113 2002/04/12 23:38:44 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.114 2002/07/23 18:19:53 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  * Copyright  1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.113 2002/04/12 23:38:44 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.114 2002/07/23 18:19:53 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -1818,22 +1818,26 @@ noGeoRequest(XmGeoMatrix _geoSpec)
 /* Keep it short and simple - make it a function (instead of a macro)
    for easier debugging purposes but give it a more than reasonable chance
    to be optimized out (or inlined in :-)  ... */
-static Boolean
-FileIsHidden(String name) {
+static inline Boolean
+FileIsHidden(String name)
+{
+	const char *ptr;
 
-  const char *ptr;
-  
-  ptr=basename(name);
-  if (*ptr=='.') {
-     ptr++;
-     if ( (*ptr=='\0') || ((*ptr=='.')&&(*(ptr+1)=='\0')) )
-       /* keep special entries visible */
-        return False;
-     else
-        return True;
-  }
-  else
-     return False;
+	ptr=basename(name);
+	if (*ptr=='.') {
+		ptr++;
+		if ( (*ptr=='\0') || ((*ptr=='.')&&(*(ptr+1)=='\0')) ) {
+			/* keep special entries visible */
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "FileIsHidden(%s) -> dot-False\n", name));
+			return False;
+		} else {
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "FileIsHidden(%s) -> True\n", name));
+			return True;
+		}
+	} else {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "FileIsHidden(%s) -> False\n", name));
+		return False;
+	}
 }
 #endif
 
@@ -1848,6 +1852,8 @@ defaultDirSearchProc(Widget widget,
     Arg argl[3];
     XmString *table;
 
+    DEBUGOUT(_LtDebug(__FILE__, widget, "defaultDirSearchProc\n"));
+
     if (!XmStringGetLtoR(cbs->dir, XmFONTLIST_DEFAULT_TAG, &dir))
     {
 	dir = XtNewString("");
