@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ImageCache.c,v 1.27 2002/02/20 21:39:16 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ImageCache.c,v 1.30 2002/11/04 19:52:45 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ImageCache.c,v 1.27 2002/02/20 21:39:16 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ImageCache.c,v 1.30 2002/11/04 19:52:45 dannybackx Exp $";
 
 /*
  * --aldi 97/01/11: changed to use the generic hashtable module.
@@ -325,6 +325,10 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 	 */
 	(PixmapValue->ref_count)++;
 
+DEBUGOUT(_LtDebug0(__FILE__, NULL,
+"XmGetPixmapByDepth(scr %p, %s, dpy %p, fg %p, bg %p, d %d) -> %p, refcnt %d\n",
+screen, image_name, DisplayOfScreen(screen), foreground, background, depth,
+PixmapValue->pixmap, PixmapValue->ref_count));
 	return PixmapValue->pixmap;
     }
 
@@ -406,6 +410,10 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 			   image->width, image->height,
 			   ImageDesc->hot_x, ImageDesc->hot_y);
 
+DEBUGOUT(_LtDebug0(__FILE__, NULL,
+"XmGetPixmapByDepth(scr %p, %s, dpy %p, fg %p, bg %p, d %d) -> %p new\n",
+screen, image_name, DisplayOfScreen(screen), foreground, background, depth,
+new_pix));
 	return new_pix;
     }
 
@@ -544,6 +552,10 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
     }
 
     XtFree(pathname_to_pixmap);
+DEBUGOUT(_LtDebug0(__FILE__, NULL,
+"XmGetPixmapByDepth(scr %p, %s, dpy %p, fg %p, bg %p, d %d) -> %p new2\n",
+screen, image_name, DisplayOfScreen(screen), foreground, background, depth,
+new_pix));
     return new_pix;
 }
 
@@ -1123,3 +1135,37 @@ XmGetScaledPixmap(Widget widget,
    return 0;
 }
 #endif /* #if XmVERSION >= 2 */
+
+/*
+ * The two functions below are an experimental attempt to clear the
+ * pixmap cache of all entries related to some screen when that screen
+ * is closed.
+ */
+static LTHashForEachIteratorResult
+YowIter(LTHashTable ht, LTHashItemID id, LTHashItemValue v, XtPointer client)
+{
+	Screen		*s = (Screen *)client;
+	LTHashItemValue	vv;
+	LTPixmapDescRec	*PixmapDesc = (LTPixmapDescRec *)v;
+
+	if (v == NULL)
+		return LTHASH_COUNT;
+
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "YowIter(%p,%p,%p,%p) - %s %p\n",
+		ht, id, v, client,
+		PixmapDesc->image_name,
+		PixmapDesc->screen));
+
+	if (s == PixmapDesc->screen)
+		(void)_LTHashTableRemoveItem(ht, id, &vv);
+	return LTHASH_COUNT;
+}
+
+void 
+_LtImageCacheScreenDestroy(Screen *s)
+{
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "_LtImageCacheScreenDestroy (XmGetPixmapByDepth) %p\n",
+		s));
+
+	(void) _LTHashTableForEachItem(PixmapCache, YowIter, (XtPointer)s);
+}
