@@ -1,6 +1,6 @@
 /**
  *
- * $Id: RCUtils.c,v 1.112 2001/05/14 20:54:10 amai Exp $
+ * $Id: RCUtils.c,v 1.113 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  * Copyright (C) 1996-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: RCUtils.c,v 1.112 2001/05/14 20:54:10 amai Exp $";
+static const char rcsid[] = "$Id: RCUtils.c,v 1.113 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -184,11 +184,11 @@ PreferredSizeHT(Widget rc, XtWidgetGeometry *rcg,
     Dimension current_y = RC_MarginH(rc) + MGR_ShadowThickness(rc);
     Dimension curh = RC_MarginH(rc) + MGR_ShadowThickness(rc);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, rc, "PreferredSizeHT("));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, rc, "%s",
+    DEBUGOUT(_LtDebug(__FILE__, rc, "PreferredSizeHT("));
+    DEBUGOUT(_LtDebug0(__FILE__, rc, "%s",
 			   RC_FromResize(rc) ? "" : "ParentResize "));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, rc, ")\n"));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, rc, "requesting %s\n",
+    DEBUGOUT(_LtDebug0(__FILE__, rc, ")\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, rc, "requesting %s\n",
 		_LtDebugWidgetGeometry2String(rcg)));
 
     *max_height = 0, *max_width = 0;
@@ -204,7 +204,7 @@ PreferredSizeHT(Widget rc, XtWidgetGeometry *rcg,
 	    continue;
 	}
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, rc, kid,
+	DEBUGOUT(_LtDebug2(__FILE__, rc, kid,
 			   "PreferredSizeHT: kid geo %d %d %dx%d\n",
 			   kid_geometry->box.x,
 			   kid_geometry->box.y,
@@ -276,7 +276,7 @@ DoLayoutHT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
     XmRCKidGeometry help_kid_geometry = NULL;
     Dimension help_kid_width = 0;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, rc, instig,
+    DEBUGOUT(_LtDebug2(__FILE__, rc, instig,
 		"DoLayoutHT: req %s, max w %d h %d\n",
 		_LtDebugWidgetGeometry2String(instig_request),
 		max_width, max_height));
@@ -495,7 +495,7 @@ PreferredSizeHC(Widget rc, XtWidgetGeometry *rcg,
     int i, nrows;
     int number_per_row;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, rc, "PreferredSizeHC()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, rc, "PreferredSizeHC()\n"));
 
     if (RC_NCol(rc) == 0)
     {
@@ -704,7 +704,7 @@ PreferredSizeVT(Widget rc, XtWidgetGeometry *rcg,
 	    continue;
 	}
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, rc, kid_geometry->kid,
+	DEBUGOUT(_LtDebug2(__FILE__, rc, kid_geometry->kid,
 			   "%p:PreferredSizeVT: kid %s\n", rc,
 			   _LtDebugWidgetGeometry2String(&kid_geometry->box)));
 
@@ -739,7 +739,7 @@ PreferredSizeVT(Widget rc, XtWidgetGeometry *rcg,
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+    DEBUGOUT(_LtDebug(__FILE__, rc,
 		      "PreferredSizeVT: MaxWidth %d\n", *max_width));
 
     rcg->request_mode = CWWidth | CWHeight | CWBorderWidth;
@@ -796,7 +796,7 @@ DoLayoutVT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	    continue;
 	}
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	DEBUGOUT(_LtDebug(__FILE__, rc,
 			  "Child %p:%s width changed to %d\n",
 			  kid, XtName(kid), max_width));
 
@@ -879,7 +879,7 @@ DoLayoutVT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 		(max_width + RC_MarginW(rc) > XtWidth(rc)))
 	    {
 		kid_geometry->box.width = max_width;
-		DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+		DEBUGOUT(_LtDebug(__FILE__, rc,
 			  "Child %p:%s AdjLast too wide width changed to %d\n",
 				  kid, XtName(kid), max_width));
 	    }
@@ -887,7 +887,7 @@ DoLayoutVT(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 	    {
 		kid_geometry->box.width = (XtWidth(rc) -
 		       (current_x + RC_MarginW(rc) + MGR_ShadowThickness(rc)));
-		DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+		DEBUGOUT(_LtDebug(__FILE__, rc,
 		      "Child %p:%s AdjLast not too wide width changed to %d\n",
 				  kid, XtName(kid), kid_geometry->box.width));
 	    }
@@ -922,7 +922,7 @@ PreferredSizeVC(Widget rc, XtWidgetGeometry *rcg,
     int i, ncols;
     int number_per_column;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+    DEBUGOUT(_LtDebug(__FILE__, rc,
 		      "PreferredSizeVC(ncols %d)\n", RC_NCol(rc)));
 
     if (RC_NCol(rc) == 0)
@@ -998,7 +998,7 @@ DoLayoutVC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
     Dimension current_x = RC_MarginW(rc) + MGR_ShadowThickness(rc);
     Dimension current_y = RC_MarginH(rc) + MGR_ShadowThickness(rc);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+    DEBUGOUT(_LtDebug(__FILE__, rc,
 		      "LayoutVC(ncols %d)\n", RC_NCol(rc)));
 
     if (RC_NCol(rc) == 0)
@@ -1045,7 +1045,7 @@ DoLayoutVC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 		/* T. Straumann: account for border width */
 		instig_request->width -= 2*kid_geometry->box.border_width;
 		instig_request->height -= 2*kid_geometry->box.border_width;
-	    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	    DEBUGOUT(_LtDebug(__FILE__, rc,
 			      "LayoutVC: instig set to %s\n",
 			      _LtDebugWidgetGeometry2String(instig_request)));
 	}
@@ -1094,7 +1094,7 @@ DoLayoutVC(Widget rc, Widget instig, XtWidgetGeometry *instig_request,
 		/* T. Straumann: account for border width */
 		instig_request->width -= 2*kid_geometry->box.border_width;
 		instig_request->height -= 2*kid_geometry->box.border_width;
-	        DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	        DEBUGOUT(_LtDebug(__FILE__, rc,
 			          "LayoutVC: instig set to %s after AdjLast\n",
 			          _LtDebugWidgetGeometry2String(instig_request)));
 	    }
@@ -1174,7 +1174,7 @@ _XmRCGetKidGeo(Widget w, Widget instig,
     Dimension mmt = 0, mmb = 0;
     XmRCKidGeometry boxes = NULL;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmRCGetKidGeo: instig %s:%s, igeo: %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmRCGetKidGeo: instig %s:%s, igeo: %s\n",
 		      instig
 			? XtClass(instig)->core_class.class_name
 			: "(null)",
@@ -1206,7 +1206,7 @@ _XmRCGetKidGeo(Widget w, Widget instig,
 	    continue;
 	}
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmRCGetKidGeo: doing change for %d %p:%s\n",
 			  i, kid_geometry->kid, XtName(kid_geometry->kid)));
 
@@ -1233,7 +1233,7 @@ _XmRCGetKidGeo(Widget w, Widget instig,
 			     instig, instig_request, &kid_geometry->box);
 	}
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmRCGetKidGeo: did change for %p:%s : geo %s\n",
 			  kid_geometry->kid, XtName(kid_geometry->kid),
 			  _LtDebugWidgetGeometry2String(&kid_geometry->box)));
@@ -1253,7 +1253,7 @@ _XmRCGetKidGeo(Widget w, Widget instig,
 	if (mmb < RCC_MarginBottom(kid_geometry->kid))
 	    mmb = RCC_MarginBottom(kid_geometry->kid);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmRCGetKidGeo: kid margins: %d %d\n",
 			  RCC_MarginTop(kid_geometry->kid),
 			  RCC_MarginBottom(kid_geometry->kid)));
@@ -1384,7 +1384,7 @@ _XmRCSetKidGeo(XmRCKidGeometry kg, Widget instigator)
     /* Now we actually lay out our children.  */
     while (kg->kid != NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, XtParent(kg->kid),
+	DEBUGOUT(_LtDebug(__FILE__, XtParent(kg->kid),
 		     "In _XmRCSetKidGeo: child %p:%s set to (%s): was %d %d\n",
 			  kg->kid, XtName(kg->kid),
 			  _LtDebugWidgetGeometry2String(&kg->box),
@@ -1454,7 +1454,7 @@ _XmRCSetMargins(Widget rc)
 	     (XmIsLabelGadget(kg->kid) &&
 	      XtClass(kg->kid) != xmLabelGadgetClass)))
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, kg->kid, "Setting margins to %d %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, kg->kid, "Setting margins to %d %d\n",
 			      kg->margin_top, kg->margin_bottom));
 	    if (RC_Orientation(rc) == XmHORIZONTAL)
 	    {
@@ -1486,7 +1486,7 @@ _XmRCSetMargins(Widget rc)
 					      kg->margin_bottom);
 		    _XmReCacheLabG(kg->kid);
 
-		    DEBUGOUT(_LtDebugDebug(__FILE__, kg->kid,
+		    DEBUGOUT(_LtDebug(__FILE__, kg->kid,
 			     "Margins now %d %d\n",
 			      LabG_MarginLeft(kg->kid),
 			      LabG_MarginRight(kg->kid)));
@@ -1526,7 +1526,7 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
     XtWidgetGeometry rcg;
     XtGeometryResult ret = XtGeometryNo;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+    DEBUGOUT(_LtDebug(__FILE__, rc,
 		      "_XmRCAdjustSize: current size %d %d instig %p\n",
 		      XtWidth(rc), XtHeight(rc), instig));
 
@@ -1541,7 +1541,7 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
 	return XtGeometryNo;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, rc, "XmRCAdjustSize (%s) %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, rc, "XmRCAdjustSize (%s) %s\n",
 		      _LtDebugRcType2String(RC_Type(rc)),
 		      RC_FromResize(rc) ? "FromResize" : ""));
 
@@ -1607,7 +1607,7 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
     if (!RC_FromResize(rc))
     {
     /* messagebox/test8, test12 budget */
-	DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	DEBUGOUT(_LtDebug(__FILE__, rc,
 			  "_XmRCAdjustSize: requesting %s from parent %s\n",
 			_LtDebugWidgetGeometry2String(&rcg), XtName(XtParent(rc))));
 
@@ -1615,7 +1615,7 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
 	{
 	    rcg.request_mode &= ~CWWidth;
 	    rcg.width = XtWidth(rc);
-	    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	    DEBUGOUT(_LtDebug(__FILE__, rc,
 			  "_XmRCAdjustSize: Dis-allow width change requesting %s from parent %s\n",
 			_LtDebugWidgetGeometry2String(&rcg), XtName(XtParent(rc))));
 	}
@@ -1623,7 +1623,7 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
 	{
 	    rcg.request_mode &= ~CWHeight;
 	    rcg.height = XtHeight(rc);
-	    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	    DEBUGOUT(_LtDebug(__FILE__, rc,
 			  "_XmRCAdjustSize: Dis-allow height change requesting %s from parent %s\n",
 			_LtDebugWidgetGeometry2String(&rcg), XtName(XtParent(rc))));
 	}
@@ -1647,13 +1647,13 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
 
 	if ((ret = _XmMakeGeometryRequest(rc, &rcg)) == XtGeometryYes)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	    DEBUGOUT(_LtDebug(__FILE__, rc,
 		       "_XmMakeGeometryRequest for RC said yes: size %d %d.\n",
 			      XtWidth(rc), XtHeight(rc)));
 	}
 	else
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	    DEBUGOUT(_LtDebug(__FILE__, rc,
 		       "_XmMakeGeometryRequest for RC %s: size stays %d %d (%s).\n",
 			      _LtDebugGeometryResult2String(ret),
 			      XtWidth(rc), XtHeight(rc),
@@ -1662,7 +1662,7 @@ _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, rc,
+	DEBUGOUT(_LtDebug(__FILE__, rc,
 			  "_XmRCAdjustSize: RC resize is %d x %d %d\n",
 			  XtWidth(rc), XtHeight(rc), XtBorderWidth(rc)));
     }
@@ -2100,7 +2100,7 @@ XmMenuPosition(Widget menu, XButtonPressedEvent *event)
 {
     int x, y;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "MENU POSITION %p %s %d %d\n", menu, XtName(menu),
 		      event->x_root, event->y_root));
 
