@@ -1,6 +1,6 @@
 /*
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ScrolledW.c,v 1.128 2002/05/02 17:25:03 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ScrolledW.c,v 1.129 2002/10/19 12:17:32 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ScrolledW.c,v 1.128 2002/05/02 17:25:03 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ScrolledW.c,v 1.129 2002/10/19 12:17:32 dannybackx Exp $";
 
 /*
  * Current status of changes in layout (Danny 18/4/1997) :
@@ -1317,9 +1317,13 @@ change_managed(Widget w)
 		for (i=0, child=0; i<MGR_NumChildren(w) && child == NULL; i++)
 			if (! XmIsScrollBar(MGR_Children(w)[i]))
 				child = MGR_Children(w)[i];
-
-		DEBUGOUT(_LtDebug2(__FILE__, w, child, "CM %d %d\n",
-			XtIsManaged(w), XtIsManaged(child)));
+		if (child) {
+			DEBUGOUT(_LtDebug2(__FILE__, w, child, "CM %d %d\n",
+				XtIsManaged(w), XtIsManaged(child)));
+		} else {
+			DEBUGOUT(_LtDebug2(__FILE__, w, child, "CM %d child NULL\n",
+				XtIsManaged(w)));
+		}
 #if 1
 		if (child && XtIsManaged(w) && !XtIsManaged(child)) {
 			DEBUGOUT(_LtDebug2(__FILE__, w, child, "Unmanage SW\n"));
