@@ -1,6 +1,6 @@
 /**
  *
- * $Id: TrackLoc.c,v 1.6 2001/05/14 19:46:11 amai Exp $
+ * $Id: TrackLoc.c,v 1.7 2001/07/27 18:51:58 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team 
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TrackLoc.c,v 1.6 2001/05/14 19:46:11 amai Exp $";
+static const char rcsid[] = "$Id: TrackLoc.c,v 1.7 2001/07/27 18:51:58 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -51,7 +51,7 @@ XmTrackingEvent(Widget widget, Cursor cursor,
 	confine_to_this = None;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmTrackingEvent: XtGrabPointer()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmTrackingEvent: XtGrabPointer()\n"));
 
     time = XtLastTimestampProcessed(XtDisplay(widget));
     if (XtGrabPointer(widget, True,
@@ -78,7 +78,7 @@ XmTrackingEvent(Widget widget, Cursor cursor,
 	    if (event_return != NULL)
 		*event_return = ev;
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	    DEBUGOUT(_LtDebug(__FILE__, widget,
 			      "XmTrackingEvent: XtUngrabPointer()\n"));
 
 	    XtUngrabPointer(widget, time);
