@@ -1,6 +1,6 @@
 /**
  *
- * $Id: VirtKeys.c,v 1.20 2001/05/17 19:44:18 amai Exp $
+ * $Id: VirtKeys.c,v 1.21 2001/07/27 18:51:58 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: VirtKeys.c,v 1.20 2001/05/17 19:44:18 amai Exp $";
+static const char rcsid[] = "$Id: VirtKeys.c,v 1.21 2001/07/27 18:51:58 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -284,7 +284,7 @@ _XmVirtualToActualKeysym(Display *Dsp,
 	    *RealKeysymReturn = (wd->display.bindings)[i].keysym;
 	    *ModifierReturn = (wd->display.bindings)[i].modifiers;
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"_XmVirtualToActualKeysym %d -> 0x%X\n",
 		VirtualKeysym, *RealKeysymReturn));
 
@@ -1073,7 +1073,7 @@ VirtKeysInitialize(Widget w)
 		       "DefaultVirtualBindings",
 		       &type, &value))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Found resource\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Found resource\n"));
 
 	/*
 	 * As long as we're not modifying the resource database during
@@ -1119,7 +1119,7 @@ VirtKeysInitialize(Widget w)
     {
 	if (bindingSpec)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Found property\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Found property\n"));
 
 	    ParseBindings(Dsp, bindingSpec);
 
@@ -1335,7 +1335,7 @@ CheckForVirtualKey(Display *Dsp, KeyCode Keycode,
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 	"CheckForVirtualKey 0x%X, mod 0x%X -> 0x%X, mod 0x%X\n",
 	Key, CurrentModifiers, *KeysymReturn, BestMods));
 }
@@ -1360,10 +1360,10 @@ XmTranslateKey(Display *Dsp, KeyCode Keycode,
      */
     XmDisplay d = (XmDisplay)XmGetXmDisplay(Dsp);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 	"XmTranslateKey (KeyCode %d, modifiers 0x%X), event %d\n",
 	Keycode, modifiers, d->display.lastKeyEvent->state));
-    DEBUGOUT(_LtDebugDebug("NMEM", NULL,
+    DEBUGOUT(_LtDebug("NMEM", NULL,
 	"XmTranslateKey (KeyCode %d, modifiers 0x%X), event %d\n",
 	Keycode, modifiers, d->display.lastKeyEvent->state));
 
@@ -1407,8 +1407,8 @@ _XmVirtKeysHandler(Widget w, XtPointer Data, XEvent *Event,
 {
     XmDisplay	d;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmVirtKeysHandler\n"));
-    DEBUGOUT(_LtDebugDebug("NMEM", w, "_XmVirtKeysHandler\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmVirtKeysHandler\n"));
+    DEBUGOUT(_LtDebug("NMEM", w, "_XmVirtKeysHandler\n"));
 
     if (!w->core.being_destroyed && (Event->xany.type == KeyPress))
     {
