@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Visual.c,v 1.34 2001/05/14 19:46:11 amai Exp $
+ * $Id: Visual.c,v 1.39 2002/03/22 07:30:02 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Visual.c,v 1.34 2001/05/14 19:46:11 amai Exp $";
+static const char rcsid[] = "$Id: Visual.c,v 1.39 2002/03/22 07:30:02 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -33,10 +33,13 @@ static const char rcsid[] = "$Id: Visual.c,v 1.34 2001/05/14 19:46:11 amai Exp $
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
-#include <Xm/PrimitiveP.h>
-#include <Xm/ManagerP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/GadgetP.h>
+#include <Xm/ManagerP.h>
+#include <Xm/MenuShellP.h>
+#include <Xm/PrimitiveP.h>
+
+#include <Xm/VendorSEP.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -312,7 +315,7 @@ _XmAddBackgroundToColorCache(Screen *screen, Colormap color_map,
 
     if (!XAllocColor(DisplayOfScreen(screen), color_map, &cd.background))
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmAddBackgroundToColorCache(%d) - Could not allocate color\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAddBackgroundToColorCache(%d) - Could not allocate color\n",
 			   __FILE__,__LINE__));
 	color_fail_warn();
 	cd.background.pixel =
@@ -394,7 +397,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->foreground))
 	    {
-		DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmFOREGROUND\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmFOREGROUND\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->foreground.pixel = black_or_white(cd, XmFOREGROUND);
@@ -409,7 +412,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->top_shadow))
 	    {
-		DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmTOP_SHADOW\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmTOP_SHADOW\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->top_shadow.pixel = black_or_white(cd, XmTOP_SHADOW);
@@ -424,7 +427,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->bottom_shadow))
 	    {
-		DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmBOTTOM_SHADOW\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmBOTTOM_SHADOW\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->bottom_shadow.pixel = black_or_white(cd, XmBOTTOM_SHADOW);
@@ -439,7 +442,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->select))
 	    {
-		DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmSELECT\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmSELECT\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->select.pixel = black_or_white(cd, XmSELECT);
@@ -989,12 +992,31 @@ _XmGetDefaultThresholdsForScreen(Screen *screen)
 /* background for everyone */
 static XtConvertArgRec backgroundArgs[] =
 {
-    {
-	XtBaseOffset, (XtPointer)XtOffsetOf(CoreRec, core.self),
-	sizeof(WidgetRec *)
-    }
+	{
+		XtBaseOffset,
+		(XtPointer)XtOffsetOf(CoreRec, core.self),
+		sizeof(WidgetRec *)
+	},
+	{
+		XtImmediate,
+		(XtPointer)XmNbackgroundPixmap,
+		sizeof(String)
+	},
 };
 
+static XtConvertArgRec pixmapArgs[] =
+{
+	{
+		XtBaseOffset,
+		(XtPointer)XtOffsetOf(CoreRec, core.self),
+		sizeof(WidgetRec *)
+	},
+	{
+		XtImmediate,
+		(XtPointer)XmNiconPixmap,
+		sizeof(String)
+	},
+};
 
 /* primitive foreground */
 static XtConvertArgRec PrimForegroundPixmapArgs[] =
@@ -1155,47 +1177,105 @@ _XmClearBGPixmap(void)
     background_pixmap_name = NULL;
 }
 
+static struct __x {
+	char	*rn, *s;
+	Widget	w;
+} *x = NULL;
+static int	nx = 0,
+		ax = 0;
+
+extern void 
+_XmPickupUnspecifiedPixmaps(Display *dpy)
+{
+	int	i, last;
+	Pixmap	p;
+
+	for (i=0; i<nx; i++)
+		if (x[i].w && XtDisplay(x[i].w) == dpy) {
+			DEBUGOUT(_LtDebug(__FILE__, x[i].w, "_XmPickupUnspecifiedPixmaps(%s,%s)\n",
+				x[i].rn, x[i].s));
+			p = XmGetPixmap(XtScreen(x[i].w),
+				x[i].s,
+				WhitePixelOfScreen(XtScreen(x[i].w)),
+				BlackPixelOfScreen(XtScreen(x[i].w)));
+
+			/* Using XtSetValues here doesn't seem to work. */
+			if (XtIsSubclass(x[i].w, vendorShellWidgetClass)) {
+				Vendor_IconPixmap(x[i].w) = p;
+			} else if (XtIsSubclass(x[i].w, xmMenuShellWidgetClass)) {
+/* I don't know what I was thinking...
+				MS_DefaultFontList(x[i].w) = p;
+				MS_ButtonFontList(x[i].w) = p;
+				MS_LabelFontList(x[i].w) = p;
+ */
+			}
+			x[i].w = NULL;
+		}
+
+	/* Clean up */
+	for (last=-1,i=0; i<nx; i++)
+		if (x[i].w) {
+			last = i;
+		}
+	nx = last+1;
+	if (nx == 0) {
+		XtFree((char *)x);
+		x = NULL;
+	}
+}
+
 static Boolean
 CvtStringToBackgroundPixmap(Display *display,
-			    XrmValuePtr args, Cardinal *num_args,
-			    XrmValuePtr fromVal, XrmValuePtr toVal,
-			    XtPointer *converter_data)
+				XrmValuePtr args, Cardinal *num_args,
+				XrmValuePtr fromVal,
+				XrmValuePtr toVal,
+				XtPointer *converter_data)
 {
-    static Pixmap buf;
+	static Pixmap	buf;
+	Widget		w = (Widget)args[0].addr;
+	String		rn = *(String *)args[1].addr,
+			s = (String)fromVal->addr;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
-		      "CvtStringToBackgroundPixmap: %s\n",
-		      fromVal->addr));
+	DEBUGOUT(_LtDebug(__FILE__, w, "CvtStringToBackgroundPixmap(%s): %s\n",
+		rn, s));
 
-    if (!XtIsShell((Widget)args[0].addr))
-    {
-	background_pixmap_name = (String)fromVal->addr;
-    }
-
-    if (toVal->addr != NULL)
-    {
-	if( toVal->size < sizeof(Pixmap))
-	{
-	    toVal->size = sizeof(Pixmap);
-
-	    return False;
+	if (XtIsShell(w)) {
+		/* Allocation */
+		if (x == 0) {
+			x = (struct __x *)XtCalloc(32, sizeof(struct __x));
+			ax = 16;
+		} else if (nx == ax) {
+			ax += 16;
+			x = (struct __x *)XtRealloc((char *)x, sizeof(struct __x) * ax);
+		}
+		/*
+		 * In a shell we need to be careful to avoid infinite recursion.
+		 * Therefore we now store the parameters that we require later
+		 * to do the conversion properly.
+		 */
+		x[nx].w = w;
+		x[nx].s = s;
+		x[nx].rn = rn;
+		nx++;
+	} else {
+		background_pixmap_name = s;
 	}
-	else
-	{
-	    *((Pixmap *)(toVal->addr)) = XmUNSPECIFIED_PIXMAP;
-	    toVal->size = sizeof(Pixmap);
 
-	    return True;
+	if (toVal->addr != NULL) {
+		if( toVal->size < sizeof(Pixmap)) {
+			toVal->size = sizeof(Pixmap);
+			return False;
+		} else {
+			*((Pixmap *)(toVal->addr)) = XmUNSPECIFIED_PIXMAP;
+			toVal->size = sizeof(Pixmap);
+			return True;
+		}
+	} else {
+		buf = XmUNSPECIFIED_PIXMAP;
+		toVal->addr = (XPointer)&buf;
+		toVal->size = sizeof(Pixmap);
+		return True;
 	}
-    }
-    else
-    {
-	buf = XmUNSPECIFIED_PIXMAP;
-	toVal->addr = (XPointer)&buf;
-	toVal->size = sizeof(Pixmap);
-
-	return True;
-    }
 }
 
 static void
@@ -1242,7 +1322,7 @@ static void
 _XmCvtStringToPrimForegroundPixmap(XrmValuePtr args, Cardinal *num_args,
 				   XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToPrimForegroundPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimForegroundPixmap\n"));
 
     BuildPixmap(XtNumber(PrimForegroundPixmapArgs),
 		"_XmCvtStringToPrimForegroundPixmap",
@@ -1253,7 +1333,7 @@ static void
 _XmCvtStringToPrimHighlightPixmap(XrmValuePtr args, Cardinal *num_args,
 				  XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToPrimHighlightPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimHighlightPixmap\n"));
 
     BuildPixmap(XtNumber(PrimHighlightPixmapArgs),
 		"_XmCvtStringToPrimHighlightPixmap",
@@ -1264,7 +1344,7 @@ static void
 _XmCvtStringToPrimTopShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				  XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToPrimTopShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimTopShadowPixmap\n"));
 
     BuildPixmap(XtNumber(PrimTopShadowPixmapArgs),
 		"_XmCvtStringToPrimTopShadowPixmap",
@@ -1275,7 +1355,7 @@ static void
 _XmCvtStringToPrimBottomShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				     XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToPrimBottomShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimBottomShadowPixmap\n"));
 
     BuildPixmap(XtNumber(PrimBottomShadowPixmapArgs),
 		"_XmCvtStringToPrimBottomShadowPixmap",
@@ -1286,7 +1366,7 @@ static void
 _XmCvtStringToManForegroundPixmap(XrmValuePtr args, Cardinal *num_args,
 				  XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToManForegroundPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManForegroundPixmap\n"));
 
     BuildPixmap(XtNumber(ManForegroundPixmapArgs),
 		"_XmCvtStringToManForegroundPixmap",
@@ -1297,7 +1377,7 @@ static void
 _XmCvtStringToManHighlightPixmap(XrmValuePtr args, Cardinal *num_args,
 				 XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToManHighlightPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManHighlightPixmap\n"));
 
     BuildPixmap(XtNumber(ManHighlightPixmapArgs),
 		"_XmCvtStringToManHighlightPixmap",
@@ -1308,7 +1388,7 @@ static void
 _XmCvtStringToManTopShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				 XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToManTopShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManTopShadowPixmap\n"));
 
     BuildPixmap(XtNumber(ManTopShadowPixmapArgs),
 		"_XmCvtStringToManTopShadowPixmap",
@@ -1319,7 +1399,7 @@ static void
 _XmCvtStringToManBottomShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				    XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToManBottomShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManBottomShadowPixmap\n"));
 
     BuildPixmap(XtNumber(ManBottomShadowPixmapArgs),
 		"_XmCvtStringToManBottomShadowPixmap",
@@ -1334,7 +1414,7 @@ _XmCvtStringToGadgetPixmap(XrmValuePtr args, Cardinal *num_args,
     Cardinal pnargs = 4;
     Widget parent;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmCvtStringToGadgetPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToGadgetPixmap\n"));
 
     parent = *((Widget *)args[0].addr);
 
@@ -1352,7 +1432,7 @@ _XmRegisterPixmapConverters(void)
 {
     static Boolean inited = False;
   
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmRegisterPixmapConverters(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmRegisterPixmapConverters(%d)\n",
 	__FILE__, __LINE__));
 
     if (inited)
@@ -1362,12 +1442,12 @@ _XmRegisterPixmapConverters(void)
 
     inited = True;
 
-    XtSetTypeConverter(XtRString, XmRXmBackgroundPixmap,
-                       CvtStringToBackgroundPixmap, backgroundArgs,
-		       XtNumber(backgroundArgs), XtCacheNone, NULL);
-    XtSetTypeConverter(XtRString, XmRPixmap,
-                       CvtStringToBackgroundPixmap, backgroundArgs,
-		       XtNumber(backgroundArgs), XtCacheNone, NULL);
+	XtSetTypeConverter(XtRString, XmRXmBackgroundPixmap,
+		CvtStringToBackgroundPixmap, backgroundArgs,
+		XtNumber(backgroundArgs), XtCacheNone, NULL);
+	XtSetTypeConverter(XtRString, XmRPixmap,
+		CvtStringToBackgroundPixmap, pixmapArgs,
+		XtNumber(pixmapArgs), XtCacheNone, NULL);
 
     XtAddConverter(XtRString, XmRPrimForegroundPixmap,
                    _XmCvtStringToPrimForegroundPixmap, PrimForegroundPixmapArgs,
@@ -1450,7 +1530,7 @@ _XmWhitePixel(Screen *screen, Colormap colormap, XColor whitecolor)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmWhitePixel(%d) - Could not allocate white color\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmWhitePixel(%d) - Could not allocate white color\n",
 			   __FILE__,__LINE__));
 	color_fail_warn();
 	last_pixel = WhitePixelOfScreen(screen);
@@ -1481,7 +1561,7 @@ _XmBlackPixel(Screen *screen, Colormap colormap, XColor blackcolor)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmBlackPixel(%d) - Could not allocate black color\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmBlackPixel(%d) - Could not allocate black color\n",
 			   __FILE__,__LINE__));
 	color_fail_warn();
 	last_pixel = BlackPixelOfScreen(screen);
