@@ -1,14 +1,23 @@
-/* $Header: /cvsroot/lesstif/lesstif/test/Xm-2.0/notebook/test1.c,v 1.8 2001/05/15 13:51:56 amai Exp $ */
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm-2.0/notebook/test1.c,v 1.10 2002/05/01 15:47:32 amai Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
-#include <Xm/XmAll.h>
+#include <Xm/Xm.h>
+#include <Xm/Form.h>
+#include <Xm/Label.h>
+#include <Xm/List.h>
+#include <Xm/MenuShell.h>
 #include <Xm/Notebook.h>
+#include <Xm/PushB.h>
+#include <Xm/RowColumn.h>
+#include <Xm/ScrolledW.h>
+#include <Xm/Separator.h>
+#include <Xm/TextF.h>
 
 #include "../../common/Test.h"
 
+
 void
 check_geometry(Widget w)
 {
