@@ -1,3 +1,6 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/dynamic_drag/drop_site_val.c,v 1.3 2001/05/23 14:03:36 amai Exp $ */
+
+#include <Xm/Xm.h>
 #include <Xm/DragDrop.h>
 
 void 
@@ -25,7 +28,7 @@ drop_site_validate(w, closure, seltype, type, value, length, format)
 		if (width != height)
 			call_data->dropSiteStatus = XmINVALID_DROP_SITE;
 		else
-			XtVaSetValues(w, XmNlabelPixmap, pixmap, 0);
+			XtVaSetValues(w, XmNlabelPixmap, pixmap, NULL);
 		call_data->animate = False;
 	}
 }
