@@ -1,16 +1,18 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/form/test5.c,v 1.7 2002/05/01 15:39:21 amai Exp $ */
 /**
  *
  * form5.c
  *
  **/
 
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <Xm/Xm.h>
 #include <Xm/PushB.h>
 #include <Xm/Form.h>
 
 #include "../../common/Test.h"
-#include "../../common/DumpLayout.h"
 
 
 void
